###THE MYTH OF THE DEMOCRATIC ADVANTAGE - REPLICATION FILE###
#Rory Truex, Assistant Professor of Politics and Public Affairs, Princeton University Department of Politics, rtruex@princeton.edu#

####LOAD DATA AND PACKAGES####
setwd('/Users/rtruex/Dropbox/Replication Files/rtruex - The Myth of the Democratic Advantage - Final Dataverse Replication Files/')
rm(list=ls(all=TRUE))

library("arm")
library("foreign")
library(Zelig)

full <- read.dta("The Myth of the Democratic Advantage - Data File.dta", convert.underscore = TRUE)
stable<-subset(full, unstable.exl==0)


###SET UP VARIABLE LIST AND BLANK MATRICES###
dvlist<-c("pupilsteachers.sec.rat", "pupilsteachers.prim.rat", "enrollmentrate.sec", "enrollmentrate.prim", "immunizdpt", "water.tot", "measles", "infantmortrate", "deathrate", "primcomp.rate", "sanitation.tot", "physicians", "beds", "lifeexpect", "fh.civilliberties","fh.press")

id<-seq(1:51)
vyear<-unique(full$year)
vyear <- vyear[order(vyear)]
blank.mat <- matrix(data = NA, nrow=length(vyear), ncol=10)
colnames(blank.mat)<-c("year","estimate", "se", "tstat","pvalue","modelnum","dv","n","lag","adjrsq")
blank.mat<-data.frame(blank.mat)
blank.mat$year<-vyear

###ALL ESTIMATES FOR GWF DEMOCRACY MEASURE###

###Democracy###
###l0###

for (i in 1:98) {
  for (k in dvlist) {
    eval(parse(text=paste("l0.",k,"output",i,"<-blank.mat",sep="")))
    eval(parse(text=paste("l0.",k,"output",i,"$modelnum<-",i,sep="")))
    eval(parse(text=paste("l0.",k,"output",i,"$lag<-0",sep=""))) 
  }
}

for (k in dvlist) {
  for (j in 16:51) {
    data<-subset(stable,year==sum(c(1959,j)))
    eval(parse(text=paste("data$publicgood<-data$",k,sep="")))
    try(model1 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model2 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model3 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model4 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model5 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model6 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model7 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model8 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ popdens, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model9 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model10 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model11 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model12 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model13 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model14 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model15 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model16 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model17 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model18 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model19 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model20 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model21 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model22 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model23 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model24 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model25 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model26 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model27 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model28 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model29 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model30 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model31 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model32 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model33 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model34 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model35 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model36 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model37 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model38 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model39 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model40 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model41 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model42 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model43 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model44 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model45 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model46 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model47 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model48 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model49 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model50 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model51 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model52 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model53 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model54 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model55 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model56 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model57 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model58 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model59 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model60 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model61 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model62 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model63 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + pop14 + pop65+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model64 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model65 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model66 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model67 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model68 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model69 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model70 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model71 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model72 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model73 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model74 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model75 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model76 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model77 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model78 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model79 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model80 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model81 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model82 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model83 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + area+ pop14 + pop65+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model84 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model85 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model86 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model87 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model88 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model89 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model90 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model91 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model92 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens+ pop14 + pop65+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model93 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model94 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model95 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model96 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model97 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model98 <- zelig(publicgood ~ democracy + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ pop14 + pop65+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)        
    for (i in 1:98) {
      try(eval(parse(text=paste("l0.",k,"output",i,"[j,2:5]<-summary(model",i,")$coefficients[2,c(1,2,3,4)]",sep=""))), silent=TRUE)
      try(eval(parse(text=paste("l0.",k,"output",i,"[j,8]<-summary(model",i,")$df[2]+summary(model",i,")$df[1]",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("l0.",k,"output",i,"[j,10]<-summary(model",i,")$adj.r.squared",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("rm(model",i,")",sep=""))), silent=TRUE)
    }
  }
}

for (k in dvlist) {
  eval(parse(text=paste("full.l0.",k,"output<-rbind(l0.",k,"output1,l0.",k,"output2,l0.",k,"output3,l0.",k,"output4,l0.",k,"output5,l0.",k,"output6,l0.",k,"output7,l0.",k,"output8,l0.",k,"output9,l0.",k,"output10,l0.",k,"output11,l0.",k,"output12,l0.",k,"output13,l0.",k,"output14,l0.",k,"output15,l0.",k,"output16,l0.",k,"output17,l0.",k,"output18,l0.",k,"output19,l0.",k,"output20,l0.",k,"output21,l0.",k,"output22,l0.",k,"output23,l0.",k,"output24,l0.",k,"output25,l0.",k,"output26,l0.",k,"output27,l0.",k,"output28,l0.",k,"output29,l0.",k,"output30,l0.",k,"output31,l0.",k,"output32,l0.",k,"output33,l0.",k,"output34,l0.",k,"output35,l0.",k,"output36,l0.",k,"output37,l0.",k,"output38,l0.",k,"output39,l0.",k,"output40,l0.",k,"output41,l0.",k,"output42,l0.",k,"output43,l0.",k,"output44,l0.",k,"output45,l0.",k,"output46,l0.",k,"output47,l0.",k,"output48,l0.",k,"output49,l0.",k,"output50,l0.",k,"output51,l0.",k,"output52,l0.",k,"output53,l0.",k,"output54,l0.",k,"output55,l0.",k,"output56,l0.",k,"output57,l0.",k,"output58,l0.",k,"output59,l0.",k,"output60,l0.",k,"output61,l0.",k,"output62,l0.",k,"output63,l0.",k,"output64,l0.",k,"output65,l0.",k,"output66,l0.",k,"output67,l0.",k,"output68,l0.",k,"output69,l0.",k,"output70,l0.",k,"output71,l0.",k,"output72,l0.",k,"output73,l0.",k,"output74,l0.",k,"output75,l0.",k,"output76,l0.",k,"output77,l0.",k,"output78,l0.",k,"output79,l0.",k,"output80,l0.",k,"output81,l0.",k,"output82,l0.",k,"output83,l0.",k,"output84,l0.",k,"output85,l0.",k,"output86,l0.",k,"output87,l0.",k,"output88,l0.",k,"output89,l0.",k,"output90,l0.",k,"output91,l0.",k,"output92,l0.",k,"output93,l0.",k,"output94,l0.",k,"output95,l0.",k,"output96,l0.",k,"output97,l0.",k,"output98)",sep="")))
}


###l1###

for (i in 1:98) {
  for (k in dvlist) {
    eval(parse(text=paste("l1.",k,"output",i,"<-blank.mat",sep="")))
    eval(parse(text=paste("l1.",k,"output",i,"$modelnum<-",i,sep="")))
    eval(parse(text=paste("l1.",k,"output",i,"$lag<-1",sep=""))) 
  }
}

for (k in dvlist) {
  for (j in 16:51) {
    data<-subset(stable,year==sum(c(1959,j)))
    eval(parse(text=paste("data$publicgood<-data$",k,sep="")))
    try(model1 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model2 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model3 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model4 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model5 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model6 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model7 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model8 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model9 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model10 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model11 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model12 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model13 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model14 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model15 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model16 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model17 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model18 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model19 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model20 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model21 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model22 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model23 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + musl80 + cath80+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model24 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + musl80 + cath80+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model25 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model26 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + pop14.l1 + pop65.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model27 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + pop14.l1 + pop65.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model28 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model29 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model30 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model31 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model32 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model33 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model34 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model35 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model36 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model37 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model38 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model39 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ musl80 + cath80+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model40 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ musl80 + cath80+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model41 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ pop14.l1 + pop65.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model42 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model43 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ pop14.l1 + pop65.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model44 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model45 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model46 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model47 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model48 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model49 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ musl80 + cath80+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model50 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ musl80 + cath80+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model51 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ pop14.l1 + pop65.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model52 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model53 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ pop14.l1 + pop65.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model54 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model55 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model56 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model57 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l1 + pop65.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model58 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model59 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l1 + pop65.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model60 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + musl80 + cath80+ pop14.l1 + pop65.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model61 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + musl80 + cath80+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model62 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + musl80 + cath80+ pop14.l1 + pop65.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model63 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + pop14.l1 + pop65.l1+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model64 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model65 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model66 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model67 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model68 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model69 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ musl80 + cath80+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model70 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ musl80 + cath80+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model71 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ pop14.l1 + pop65.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model72 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model73 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ pop14.l1 + pop65.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model74 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model75 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model76 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model77 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l1 + pop65.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model78 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model79 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l1 + pop65.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model80 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ musl80 + cath80+ pop14.l1 + pop65.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model81 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ musl80 + cath80+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model82 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ musl80 + cath80+ pop14.l1 + pop65.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model83 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ pop14.l1 + pop65.l1+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model84 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model85 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model86 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l1 + pop65.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model87 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model88 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l1 + pop65.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model89 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ musl80 + cath80+ pop14.l1 + pop65.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model90 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ musl80 + cath80+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model91 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ musl80 + cath80+ pop14.l1 + pop65.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model92 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ pop14.l1 + pop65.l1+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model93 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l1 + pop65.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model94 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model95 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model96 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l1 + pop65.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model97 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l1 + pop65.l1+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model98 <- zelig(publicgood ~ democracy.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + musl80 + cath80+ pop14.l1 + pop65.l1+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)        
    for (i in 1:98) {
      try(eval(parse(text=paste("l1.",k,"output",i,"[j,2:5]<-summary(model",i,")$coefficients[2,c(1,2,3,4)]",sep=""))), silent=TRUE)
      try(eval(parse(text=paste("l1.",k,"output",i,"[j,8]<-summary(model",i,")$df[2]+summary(model",i,")$df[1]",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("l1.",k,"output",i,"[j,10]<-summary(model",i,")$adj.r.squared",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("rm(model",i,")",sep=""))), silent=TRUE)
    }
  }
}

for (k in dvlist) {
  eval(parse(text=paste("full.l1.",k,"output<-rbind(l1.",k,"output1,l1.",k,"output2,l1.",k,"output3,l1.",k,"output4,l1.",k,"output5,l1.",k,"output6,l1.",k,"output7,l1.",k,"output8,l1.",k,"output9,l1.",k,"output10,l1.",k,"output11,l1.",k,"output12,l1.",k,"output13,l1.",k,"output14,l1.",k,"output15,l1.",k,"output16,l1.",k,"output17,l1.",k,"output18,l1.",k,"output19,l1.",k,"output20,l1.",k,"output21,l1.",k,"output22,l1.",k,"output23,l1.",k,"output24,l1.",k,"output25,l1.",k,"output26,l1.",k,"output27,l1.",k,"output28,l1.",k,"output29,l1.",k,"output30,l1.",k,"output31,l1.",k,"output32,l1.",k,"output33,l1.",k,"output34,l1.",k,"output35,l1.",k,"output36,l1.",k,"output37,l1.",k,"output38,l1.",k,"output39,l1.",k,"output40,l1.",k,"output41,l1.",k,"output42,l1.",k,"output43,l1.",k,"output44,l1.",k,"output45,l1.",k,"output46,l1.",k,"output47,l1.",k,"output48,l1.",k,"output49,l1.",k,"output50,l1.",k,"output51,l1.",k,"output52,l1.",k,"output53,l1.",k,"output54,l1.",k,"output55,l1.",k,"output56,l1.",k,"output57,l1.",k,"output58,l1.",k,"output59,l1.",k,"output60,l1.",k,"output61,l1.",k,"output62,l1.",k,"output63,l1.",k,"output64,l1.",k,"output65,l1.",k,"output66,l1.",k,"output67,l1.",k,"output68,l1.",k,"output69,l1.",k,"output70,l1.",k,"output71,l1.",k,"output72,l1.",k,"output73,l1.",k,"output74,l1.",k,"output75,l1.",k,"output76,l1.",k,"output77,l1.",k,"output78,l1.",k,"output79,l1.",k,"output80,l1.",k,"output81,l1.",k,"output82,l1.",k,"output83,l1.",k,"output84,l1.",k,"output85,l1.",k,"output86,l1.",k,"output87,l1.",k,"output88,l1.",k,"output89,l1.",k,"output90,l1.",k,"output91,l1.",k,"output92,l1.",k,"output93,l1.",k,"output94,l1.",k,"output95,l1.",k,"output96,l1.",k,"output97,l1.",k,"output98)",sep="")))
}

###l2####

for (i in 1:98) {
  for (k in dvlist) {
    eval(parse(text=paste("l2.",k,"output",i,"<-blank.mat",sep="")))
    eval(parse(text=paste("l2.",k,"output",i,"$modelnum<-",i,sep="")))
    eval(parse(text=paste("l2.",k,"output",i,"$lag<-2",sep=""))) 
  }
}

for (k in dvlist) {
  for (j in 16:51) {
    data<-subset(stable,year==sum(c(1959,j)))
    eval(parse(text=paste("data$publicgood<-data$",k,sep="")))
    try(model1 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model2 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model3 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model4 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model5 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model6 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model7 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model8 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model9 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model10 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model11 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model12 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model13 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model14 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model15 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model16 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model17 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model18 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model19 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model20 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model21 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model22 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model23 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + musl80 + cath80+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model24 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + musl80 + cath80+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model25 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model26 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + pop14.l2 + pop65.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model27 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + pop14.l2 + pop65.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model28 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model29 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model30 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model31 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model32 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model33 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model34 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model35 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model36 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model37 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model38 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model39 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ musl80 + cath80+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model40 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ musl80 + cath80+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model41 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ pop14.l2 + pop65.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model42 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model43 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ pop14.l2 + pop65.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model44 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model45 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model46 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model47 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model48 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model49 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ musl80 + cath80+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model50 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ musl80 + cath80+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model51 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ pop14.l2 + pop65.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model52 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model53 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ pop14.l2 + pop65.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model54 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model55 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model56 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model57 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l2 + pop65.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model58 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model59 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l2 + pop65.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model60 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + musl80 + cath80+ pop14.l2 + pop65.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model61 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + musl80 + cath80+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model62 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + musl80 + cath80+ pop14.l2 + pop65.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model63 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + pop14.l2 + pop65.l2+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model64 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model65 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model66 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model67 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model68 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model69 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ musl80 + cath80+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model70 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ musl80 + cath80+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model71 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ pop14.l2 + pop65.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model72 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model73 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ pop14.l2 + pop65.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model74 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model75 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model76 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model77 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l2 + pop65.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model78 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model79 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l2 + pop65.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model80 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ musl80 + cath80+ pop14.l2 + pop65.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model81 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ musl80 + cath80+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model82 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ musl80 + cath80+ pop14.l2 + pop65.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model83 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ pop14.l2 + pop65.l2+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model84 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model85 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model86 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l2 + pop65.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model87 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model88 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l2 + pop65.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model89 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ musl80 + cath80+ pop14.l2 + pop65.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model90 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ musl80 + cath80+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model91 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ musl80 + cath80+ pop14.l2 + pop65.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model92 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ pop14.l2 + pop65.l2+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model93 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l2 + pop65.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model94 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model95 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model96 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l2 + pop65.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model97 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l2 + pop65.l2+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model98 <- zelig(publicgood ~ democracy.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + musl80 + cath80+ pop14.l2 + pop65.l2+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)        
    for (i in 1:98) {
      try(eval(parse(text=paste("l2.",k,"output",i,"[j,2:5]<-summary(model",i,")$coefficients[2,c(1,2,3,4)]",sep=""))), silent=TRUE)
      try(eval(parse(text=paste("l2.",k,"output",i,"[j,8]<-summary(model",i,")$df[2]+summary(model",i,")$df[1]",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("l2.",k,"output",i,"[j,10]<-summary(model",i,")$adj.r.squared",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("rm(model",i,")",sep=""))), silent=TRUE)
    }
  }
}

for (k in dvlist) {
  eval(parse(text=paste("full.l2.",k,"output<-rbind(l2.",k,"output1,l2.",k,"output2,l2.",k,"output3,l2.",k,"output4,l2.",k,"output5,l2.",k,"output6,l2.",k,"output7,l2.",k,"output8,l2.",k,"output9,l2.",k,"output10,l2.",k,"output11,l2.",k,"output12,l2.",k,"output13,l2.",k,"output14,l2.",k,"output15,l2.",k,"output16,l2.",k,"output17,l2.",k,"output18,l2.",k,"output19,l2.",k,"output20,l2.",k,"output21,l2.",k,"output22,l2.",k,"output23,l2.",k,"output24,l2.",k,"output25,l2.",k,"output26,l2.",k,"output27,l2.",k,"output28,l2.",k,"output29,l2.",k,"output30,l2.",k,"output31,l2.",k,"output32,l2.",k,"output33,l2.",k,"output34,l2.",k,"output35,l2.",k,"output36,l2.",k,"output37,l2.",k,"output38,l2.",k,"output39,l2.",k,"output40,l2.",k,"output41,l2.",k,"output42,l2.",k,"output43,l2.",k,"output44,l2.",k,"output45,l2.",k,"output46,l2.",k,"output47,l2.",k,"output48,l2.",k,"output49,l2.",k,"output50,l2.",k,"output51,l2.",k,"output52,l2.",k,"output53,l2.",k,"output54,l2.",k,"output55,l2.",k,"output56,l2.",k,"output57,l2.",k,"output58,l2.",k,"output59,l2.",k,"output60,l2.",k,"output61,l2.",k,"output62,l2.",k,"output63,l2.",k,"output64,l2.",k,"output65,l2.",k,"output66,l2.",k,"output67,l2.",k,"output68,l2.",k,"output69,l2.",k,"output70,l2.",k,"output71,l2.",k,"output72,l2.",k,"output73,l2.",k,"output74,l2.",k,"output75,l2.",k,"output76,l2.",k,"output77,l2.",k,"output78,l2.",k,"output79,l2.",k,"output80,l2.",k,"output81,l2.",k,"output82,l2.",k,"output83,l2.",k,"output84,l2.",k,"output85,l2.",k,"output86,l2.",k,"output87,l2.",k,"output88,l2.",k,"output89,l2.",k,"output90,l2.",k,"output91,l2.",k,"output92,l2.",k,"output93,l2.",k,"output94,l2.",k,"output95,l2.",k,"output96,l2.",k,"output97,l2.",k,"output98)",sep="")))
}

for (i in 1:98) {
  for (k in dvlist) {
    eval(parse(text=paste("l3.",k,"output",i,"<-blank.mat",sep="")))
    eval(parse(text=paste("l3.",k,"output",i,"$modelnum<-",i,sep="")))
    eval(parse(text=paste("l3.",k,"output",i,"$lag<-3",sep=""))) 
  }
}

for (k in dvlist) {
  for (j in 16:51) {
    data<-subset(stable,year==sum(c(1959,j)))
    eval(parse(text=paste("data$publicgood<-data$",k,sep="")))
    try(model1 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model2 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model3 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model4 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model5 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model6 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model7 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model8 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model9 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model10 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model11 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model12 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model13 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model14 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model15 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model16 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model17 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model18 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model19 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model20 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model21 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model22 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model23 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + musl80 + cath80+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model24 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + musl80 + cath80+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model25 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model26 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + pop14.l3 + pop65.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model27 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + pop14.l3 + pop65.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model28 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model29 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model30 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model31 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model32 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model33 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model34 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model35 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model36 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model37 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model38 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model39 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ musl80 + cath80+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model40 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ musl80 + cath80+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model41 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ pop14.l3 + pop65.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model42 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model43 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ pop14.l3 + pop65.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model44 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model45 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model46 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model47 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model48 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model49 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ musl80 + cath80+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model50 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ musl80 + cath80+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model51 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ pop14.l3 + pop65.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model52 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model53 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ pop14.l3 + pop65.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model54 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model55 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model56 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model57 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l3 + pop65.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model58 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model59 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l3 + pop65.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model60 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + musl80 + cath80+ pop14.l3 + pop65.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model61 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + musl80 + cath80+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model62 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + musl80 + cath80+ pop14.l3 + pop65.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model63 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + pop14.l3 + pop65.l3+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model64 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model65 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model66 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model67 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model68 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model69 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ musl80 + cath80+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model70 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ musl80 + cath80+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model71 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ pop14.l3 + pop65.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model72 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model73 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ pop14.l3 + pop65.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model74 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model75 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model76 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model77 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l3 + pop65.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model78 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model79 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l3 + pop65.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model80 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ musl80 + cath80+ pop14.l3 + pop65.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model81 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ musl80 + cath80+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model82 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ musl80 + cath80+ pop14.l3 + pop65.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model83 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ pop14.l3 + pop65.l3+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model84 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model85 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model86 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l3 + pop65.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model87 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model88 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l3 + pop65.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model89 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ musl80 + cath80+ pop14.l3 + pop65.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model90 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ musl80 + cath80+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model91 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ musl80 + cath80+ pop14.l3 + pop65.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model92 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ pop14.l3 + pop65.l3+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model93 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l3 + pop65.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model94 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model95 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model96 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l3 + pop65.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model97 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l3 + pop65.l3+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model98 <- zelig(publicgood ~ democracy.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + musl80 + cath80+ pop14.l3 + pop65.l3+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)        
    for (i in 1:98) {
      try(eval(parse(text=paste("l3.",k,"output",i,"[j,2:5]<-summary(model",i,")$coefficients[2,c(1,2,3,4)]",sep=""))), silent=TRUE)
      try(eval(parse(text=paste("l3.",k,"output",i,"[j,8]<-summary(model",i,")$df[2]+summary(model",i,")$df[1]",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("l3.",k,"output",i,"[j,10]<-summary(model",i,")$adj.r.squared",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("rm(model",i,")",sep=""))), silent=TRUE)
    }
  }
}

for (k in dvlist) {
  eval(parse(text=paste("full.l3.",k,"output<-rbind(l3.",k,"output1,l3.",k,"output2,l3.",k,"output3,l3.",k,"output4,l3.",k,"output5,l3.",k,"output6,l3.",k,"output7,l3.",k,"output8,l3.",k,"output9,l3.",k,"output10,l3.",k,"output11,l3.",k,"output12,l3.",k,"output13,l3.",k,"output14,l3.",k,"output15,l3.",k,"output16,l3.",k,"output17,l3.",k,"output18,l3.",k,"output19,l3.",k,"output20,l3.",k,"output21,l3.",k,"output22,l3.",k,"output23,l3.",k,"output24,l3.",k,"output25,l3.",k,"output26,l3.",k,"output27,l3.",k,"output28,l3.",k,"output29,l3.",k,"output30,l3.",k,"output31,l3.",k,"output32,l3.",k,"output33,l3.",k,"output34,l3.",k,"output35,l3.",k,"output36,l3.",k,"output37,l3.",k,"output38,l3.",k,"output39,l3.",k,"output40,l3.",k,"output41,l3.",k,"output42,l3.",k,"output43,l3.",k,"output44,l3.",k,"output45,l3.",k,"output46,l3.",k,"output47,l3.",k,"output48,l3.",k,"output49,l3.",k,"output50,l3.",k,"output51,l3.",k,"output52,l3.",k,"output53,l3.",k,"output54,l3.",k,"output55,l3.",k,"output56,l3.",k,"output57,l3.",k,"output58,l3.",k,"output59,l3.",k,"output60,l3.",k,"output61,l3.",k,"output62,l3.",k,"output63,l3.",k,"output64,l3.",k,"output65,l3.",k,"output66,l3.",k,"output67,l3.",k,"output68,l3.",k,"output69,l3.",k,"output70,l3.",k,"output71,l3.",k,"output72,l3.",k,"output73,l3.",k,"output74,l3.",k,"output75,l3.",k,"output76,l3.",k,"output77,l3.",k,"output78,l3.",k,"output79,l3.",k,"output80,l3.",k,"output81,l3.",k,"output82,l3.",k,"output83,l3.",k,"output84,l3.",k,"output85,l3.",k,"output86,l3.",k,"output87,l3.",k,"output88,l3.",k,"output89,l3.",k,"output90,l3.",k,"output91,l3.",k,"output92,l3.",k,"output93,l3.",k,"output94,l3.",k,"output95,l3.",k,"output96,l3.",k,"output97,l3.",k,"output98)",sep="")))
}

for (i in 1:98) {
  for (k in dvlist) {
    eval(parse(text=paste("l4.",k,"output",i,"<-blank.mat",sep="")))
    eval(parse(text=paste("l4.",k,"output",i,"$modelnum<-",i,sep="")))
    eval(parse(text=paste("l4.",k,"output",i,"$lag<-4",sep=""))) 
  }
}

for (k in dvlist) {
  for (j in 16:51) {
    data<-subset(stable,year==sum(c(1959,j)))
    eval(parse(text=paste("data$publicgood<-data$",k,sep="")))
    try(model1 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model2 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model3 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model4 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model5 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model6 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model7 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model8 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model9 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model10 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model11 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model12 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model13 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model14 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model15 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model16 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model17 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model18 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model19 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model20 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model21 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model22 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model23 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + musl80 + cath80+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model24 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + musl80 + cath80+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model25 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model26 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + pop14.l4 + pop65.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model27 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + pop14.l4 + pop65.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model28 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model29 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model30 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model31 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model32 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model33 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model34 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model35 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model36 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model37 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model38 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model39 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ musl80 + cath80+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model40 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ musl80 + cath80+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model41 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ pop14.l4 + pop65.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model42 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model43 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ pop14.l4 + pop65.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model44 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model45 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model46 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model47 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model48 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model49 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ musl80 + cath80+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model50 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ musl80 + cath80+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model51 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ pop14.l4 + pop65.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model52 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model53 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ pop14.l4 + pop65.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model54 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model55 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model56 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model57 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l4 + pop65.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model58 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model59 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l4 + pop65.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model60 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + musl80 + cath80+ pop14.l4 + pop65.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model61 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + musl80 + cath80+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model62 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + musl80 + cath80+ pop14.l4 + pop65.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model63 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + pop14.l4 + pop65.l4+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model64 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model65 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model66 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model67 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model68 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model69 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ musl80 + cath80+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model70 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ musl80 + cath80+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model71 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ pop14.l4 + pop65.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model72 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model73 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ pop14.l4 + pop65.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model74 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model75 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model76 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model77 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l4 + pop65.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model78 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model79 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l4 + pop65.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model80 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ musl80 + cath80+ pop14.l4 + pop65.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model81 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ musl80 + cath80+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model82 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ musl80 + cath80+ pop14.l4 + pop65.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model83 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ pop14.l4 + pop65.l4+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model84 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model85 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model86 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l4 + pop65.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model87 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model88 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l4 + pop65.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model89 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ musl80 + cath80+ pop14.l4 + pop65.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model90 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ musl80 + cath80+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model91 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ musl80 + cath80+ pop14.l4 + pop65.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model92 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ pop14.l4 + pop65.l4+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model93 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l4 + pop65.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model94 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model95 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model96 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l4 + pop65.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model97 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l4 + pop65.l4+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model98 <- zelig(publicgood ~ democracy.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + musl80 + cath80+ pop14.l4 + pop65.l4+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)        
    for (i in 1:98) {
      try(eval(parse(text=paste("l4.",k,"output",i,"[j,2:5]<-summary(model",i,")$coefficients[2,c(1,2,3,4)]",sep=""))), silent=TRUE)
      try(eval(parse(text=paste("l4.",k,"output",i,"[j,8]<-summary(model",i,")$df[2]+summary(model",i,")$df[1]",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("l4.",k,"output",i,"[j,10]<-summary(model",i,")$adj.r.squared",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("rm(model",i,")",sep=""))), silent=TRUE)
    }
  }
}

for (k in dvlist) {
  eval(parse(text=paste("full.l4.",k,"output<-rbind(l4.",k,"output1,l4.",k,"output2,l4.",k,"output3,l4.",k,"output4,l4.",k,"output5,l4.",k,"output6,l4.",k,"output7,l4.",k,"output8,l4.",k,"output9,l4.",k,"output10,l4.",k,"output11,l4.",k,"output12,l4.",k,"output13,l4.",k,"output14,l4.",k,"output15,l4.",k,"output16,l4.",k,"output17,l4.",k,"output18,l4.",k,"output19,l4.",k,"output20,l4.",k,"output21,l4.",k,"output22,l4.",k,"output23,l4.",k,"output24,l4.",k,"output25,l4.",k,"output26,l4.",k,"output27,l4.",k,"output28,l4.",k,"output29,l4.",k,"output30,l4.",k,"output31,l4.",k,"output32,l4.",k,"output33,l4.",k,"output34,l4.",k,"output35,l4.",k,"output36,l4.",k,"output37,l4.",k,"output38,l4.",k,"output39,l4.",k,"output40,l4.",k,"output41,l4.",k,"output42,l4.",k,"output43,l4.",k,"output44,l4.",k,"output45,l4.",k,"output46,l4.",k,"output47,l4.",k,"output48,l4.",k,"output49,l4.",k,"output50,l4.",k,"output51,l4.",k,"output52,l4.",k,"output53,l4.",k,"output54,l4.",k,"output55,l4.",k,"output56,l4.",k,"output57,l4.",k,"output58,l4.",k,"output59,l4.",k,"output60,l4.",k,"output61,l4.",k,"output62,l4.",k,"output63,l4.",k,"output64,l4.",k,"output65,l4.",k,"output66,l4.",k,"output67,l4.",k,"output68,l4.",k,"output69,l4.",k,"output70,l4.",k,"output71,l4.",k,"output72,l4.",k,"output73,l4.",k,"output74,l4.",k,"output75,l4.",k,"output76,l4.",k,"output77,l4.",k,"output78,l4.",k,"output79,l4.",k,"output80,l4.",k,"output81,l4.",k,"output82,l4.",k,"output83,l4.",k,"output84,l4.",k,"output85,l4.",k,"output86,l4.",k,"output87,l4.",k,"output88,l4.",k,"output89,l4.",k,"output90,l4.",k,"output91,l4.",k,"output92,l4.",k,"output93,l4.",k,"output94,l4.",k,"output95,l4.",k,"output96,l4.",k,"output97,l4.",k,"output98)",sep="")))
}

for (i in 1:98) {
  for (k in dvlist) {
    eval(parse(text=paste("l5.",k,"output",i,"<-blank.mat",sep="")))
    eval(parse(text=paste("l5.",k,"output",i,"$modelnum<-",i,sep="")))
    eval(parse(text=paste("l5.",k,"output",i,"$lag<-5",sep=""))) 
  }
}

for (k in dvlist) {
  for (j in 16:51) {
    data<-subset(stable,year==sum(c(1959,j)))
    eval(parse(text=paste("data$publicgood<-data$",k,sep="")))
    try(model1 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model2 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model3 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model4 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model5 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model6 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model7 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model8 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model9 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model10 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model11 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model12 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model13 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model14 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model15 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model16 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model17 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model18 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model19 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model20 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model21 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model22 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model23 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + musl80 + cath80+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model24 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + musl80 + cath80+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model25 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model26 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + pop14.l5 + pop65.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model27 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + pop14.l5 + pop65.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model28 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model29 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model30 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model31 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model32 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model33 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model34 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model35 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model36 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model37 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model38 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model39 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ musl80 + cath80+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model40 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ musl80 + cath80+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model41 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ pop14.l5 + pop65.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model42 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model43 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ pop14.l5 + pop65.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model44 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model45 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model46 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model47 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model48 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model49 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ musl80 + cath80+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model50 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ musl80 + cath80+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model51 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ pop14.l5 + pop65.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model52 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model53 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ pop14.l5 + pop65.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model54 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model55 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model56 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model57 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l5 + pop65.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model58 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model59 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l5 + pop65.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model60 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + musl80 + cath80+ pop14.l5 + pop65.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model61 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + musl80 + cath80+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model62 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + musl80 + cath80+ pop14.l5 + pop65.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model63 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + pop14.l5 + pop65.l5+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model64 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model65 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model66 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model67 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model68 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model69 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ musl80 + cath80+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model70 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ musl80 + cath80+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model71 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ pop14.l5 + pop65.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model72 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model73 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ pop14.l5 + pop65.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model74 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model75 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model76 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model77 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l5 + pop65.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model78 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model79 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l5 + pop65.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model80 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ musl80 + cath80+ pop14.l5 + pop65.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model81 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ musl80 + cath80+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model82 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ musl80 + cath80+ pop14.l5 + pop65.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model83 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ pop14.l5 + pop65.l5+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model84 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model85 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model86 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l5 + pop65.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model87 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model88 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l5 + pop65.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model89 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ musl80 + cath80+ pop14.l5 + pop65.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model90 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ musl80 + cath80+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model91 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ musl80 + cath80+ pop14.l5 + pop65.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model92 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ pop14.l5 + pop65.l5+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model93 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l5 + pop65.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model94 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model95 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model96 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l5 + pop65.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model97 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l5 + pop65.l5+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model98 <- zelig(publicgood ~ democracy.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + musl80 + cath80+ pop14.l5 + pop65.l5+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)        
    for (i in 1:98) {
      try(eval(parse(text=paste("l5.",k,"output",i,"[j,2:5]<-summary(model",i,")$coefficients[2,c(1,2,3,4)]",sep=""))), silent=TRUE)
      try(eval(parse(text=paste("l5.",k,"output",i,"[j,8]<-summary(model",i,")$df[2]+summary(model",i,")$df[1]",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("l5.",k,"output",i,"[j,10]<-summary(model",i,")$adj.r.squared",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("rm(model",i,")",sep=""))), silent=TRUE)
    }
  }
}

for (k in dvlist) {
  eval(parse(text=paste("full.l5.",k,"output<-rbind(l5.",k,"output1,l5.",k,"output2,l5.",k,"output3,l5.",k,"output4,l5.",k,"output5,l5.",k,"output6,l5.",k,"output7,l5.",k,"output8,l5.",k,"output9,l5.",k,"output10,l5.",k,"output11,l5.",k,"output12,l5.",k,"output13,l5.",k,"output14,l5.",k,"output15,l5.",k,"output16,l5.",k,"output17,l5.",k,"output18,l5.",k,"output19,l5.",k,"output20,l5.",k,"output21,l5.",k,"output22,l5.",k,"output23,l5.",k,"output24,l5.",k,"output25,l5.",k,"output26,l5.",k,"output27,l5.",k,"output28,l5.",k,"output29,l5.",k,"output30,l5.",k,"output31,l5.",k,"output32,l5.",k,"output33,l5.",k,"output34,l5.",k,"output35,l5.",k,"output36,l5.",k,"output37,l5.",k,"output38,l5.",k,"output39,l5.",k,"output40,l5.",k,"output41,l5.",k,"output42,l5.",k,"output43,l5.",k,"output44,l5.",k,"output45,l5.",k,"output46,l5.",k,"output47,l5.",k,"output48,l5.",k,"output49,l5.",k,"output50,l5.",k,"output51,l5.",k,"output52,l5.",k,"output53,l5.",k,"output54,l5.",k,"output55,l5.",k,"output56,l5.",k,"output57,l5.",k,"output58,l5.",k,"output59,l5.",k,"output60,l5.",k,"output61,l5.",k,"output62,l5.",k,"output63,l5.",k,"output64,l5.",k,"output65,l5.",k,"output66,l5.",k,"output67,l5.",k,"output68,l5.",k,"output69,l5.",k,"output70,l5.",k,"output71,l5.",k,"output72,l5.",k,"output73,l5.",k,"output74,l5.",k,"output75,l5.",k,"output76,l5.",k,"output77,l5.",k,"output78,l5.",k,"output79,l5.",k,"output80,l5.",k,"output81,l5.",k,"output82,l5.",k,"output83,l5.",k,"output84,l5.",k,"output85,l5.",k,"output86,l5.",k,"output87,l5.",k,"output88,l5.",k,"output89,l5.",k,"output90,l5.",k,"output91,l5.",k,"output92,l5.",k,"output93,l5.",k,"output94,l5.",k,"output95,l5.",k,"output96,l5.",k,"output97,l5.",k,"output98)",sep="")))
  eval(parse(text=paste("full.l5.",k,"output$lag=5",sep="")))
}

###CREATING FINAL OUTPUT###

for (k in dvlist) {
  eval(parse(text=paste(k,".democracy.finaloutput<-rbind(full.l0.",k,"output, full.l1.",k,"output, full.l2.",k,"output, full.l3.",k,"output, full.l4.",k,"output, full.l5.",k,"output)",sep="")))
}



fh.civilliberties.democracy.finaloutput$dv="fh.civilliberties"
fh.press.democracy.finaloutput$dv="fh.press"
deathrate.democracy.finaloutput$dv="deathrate"
infantmortrate.democracy.finaloutput$dv="infantmortrate"
immunizdpt.democracy.finaloutput$dv="immunizdpt"
measles.democracy.finaloutput$dv="measles"
water.tot.democracy.finaloutput$dv="water.tot"
pupilsteachers.prim.rat.democracy.finaloutput$dv="pupilsteachers.prim.rat"
pupilsteachers.sec.rat.democracy.finaloutput$dv="pupilsteachers.sec.rat"
enrollmentrate.sec.democracy.finaloutput$dv="enrollmentrate.sec"
enrollmentrate.prim.democracy.finaloutput$dv="enrollmentrate.prim"
primcomp.rate.democracy.finaloutput$dv="primcomp.rate"
sanitation.tot.democracy.finaloutput$dv="sanitation.tot"
physicians.democracy.finaloutput$dv="physicians"
beds.democracy.finaloutput$dv="beds"
lifeexpect.democracy.finaloutput$dv="lifeexpect"


democracy.finaloutput.combined<-rbind(deathrate.democracy.finaloutput, infantmortrate.democracy.finaloutput, immunizdpt.democracy.finaloutput, measles.democracy.finaloutput, water.tot.democracy.finaloutput, pupilsteachers.prim.rat.democracy.finaloutput, pupilsteachers.sec.rat.democracy.finaloutput, enrollmentrate.sec.democracy.finaloutput, enrollmentrate.prim.democracy.finaloutput, primcomp.rate.democracy.finaloutput, sanitation.tot.democracy.finaloutput, physicians.democracy.finaloutput, beds.democracy.finaloutput, lifeexpect.democracy.finaloutput,fh.civilliberties.democracy.finaloutput, fh.press.democracy.finaloutput)
write.dta(democracy.finaloutput.combined,"democracy.finaloutput.combined.dta")
rm(list=ls(all=TRUE))


###ALL ESTIMATES FOR POLITY2 MEASURE###

###Polity2###
###l0###

for (i in 1:98) {
  for (k in dvlist) {
    eval(parse(text=paste("l0.",k,"output",i,"<-blank.mat",sep="")))
    eval(parse(text=paste("l0.",k,"output",i,"$modelnum<-",i,sep="")))
    eval(parse(text=paste("l0.",k,"output",i,"$lag<-0",sep=""))) 
  }
}

for (k in dvlist) {
  for (j in 16:51) {
    data<-subset(stable,year==sum(c(1959,j)))
    eval(parse(text=paste("data$publicgood<-data$",k,sep="")))
    try(model1 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model2 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model3 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model4 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model5 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model6 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model7 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model8 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model9 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model10 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model11 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model12 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model13 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model14 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model15 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model16 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model17 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model18 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model19 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model20 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model21 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model22 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model23 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model24 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model25 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model26 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model27 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model28 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model29 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model30 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model31 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model32 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model33 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model34 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model35 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model36 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model37 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model38 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model39 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model40 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model41 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model42 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model43 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model44 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model45 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model46 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model47 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model48 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model49 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model50 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model51 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model52 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model53 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model54 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model55 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model56 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model57 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model58 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model59 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model60 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model61 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model62 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model63 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + pop14 + pop65+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model64 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model65 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model66 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model67 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model68 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model69 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model70 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model71 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model72 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model73 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model74 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model75 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model76 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model77 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model78 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model79 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model80 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model81 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model82 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model83 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ pop14 + pop65+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model84 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model85 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model86 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model87 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model88 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model89 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model90 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model91 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model92 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ pop14 + pop65+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model93 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model94 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model95 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model96 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model97 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model98 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ pop14 + pop65+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)        
    for (i in 1:98) {
      try(eval(parse(text=paste("l0.",k,"output",i,"[j,2:5]<-summary(model",i,")$coefficients[2,c(1,2,3,4)]",sep=""))), silent=TRUE)
      try(eval(parse(text=paste("l0.",k,"output",i,"[j,8]<-summary(model",i,")$df[2]+summary(model",i,")$df[1]",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("l0.",k,"output",i,"[j,10]<-summary(model",i,")$adj.r.squared",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("rm(model",i,")",sep=""))), silent=TRUE)
    }
  }
}

for (k in dvlist) {
  eval(parse(text=paste("full.l0.",k,"output<-rbind(l0.",k,"output1,l0.",k,"output2,l0.",k,"output3,l0.",k,"output4,l0.",k,"output5,l0.",k,"output6,l0.",k,"output7,l0.",k,"output8,l0.",k,"output9,l0.",k,"output10,l0.",k,"output11,l0.",k,"output12,l0.",k,"output13,l0.",k,"output14,l0.",k,"output15,l0.",k,"output16,l0.",k,"output17,l0.",k,"output18,l0.",k,"output19,l0.",k,"output20,l0.",k,"output21,l0.",k,"output22,l0.",k,"output23,l0.",k,"output24,l0.",k,"output25,l0.",k,"output26,l0.",k,"output27,l0.",k,"output28,l0.",k,"output29,l0.",k,"output30,l0.",k,"output31,l0.",k,"output32,l0.",k,"output33,l0.",k,"output34,l0.",k,"output35,l0.",k,"output36,l0.",k,"output37,l0.",k,"output38,l0.",k,"output39,l0.",k,"output40,l0.",k,"output41,l0.",k,"output42,l0.",k,"output43,l0.",k,"output44,l0.",k,"output45,l0.",k,"output46,l0.",k,"output47,l0.",k,"output48,l0.",k,"output49,l0.",k,"output50,l0.",k,"output51,l0.",k,"output52,l0.",k,"output53,l0.",k,"output54,l0.",k,"output55,l0.",k,"output56,l0.",k,"output57,l0.",k,"output58,l0.",k,"output59,l0.",k,"output60,l0.",k,"output61,l0.",k,"output62,l0.",k,"output63,l0.",k,"output64,l0.",k,"output65,l0.",k,"output66,l0.",k,"output67,l0.",k,"output68,l0.",k,"output69,l0.",k,"output70,l0.",k,"output71,l0.",k,"output72,l0.",k,"output73,l0.",k,"output74,l0.",k,"output75,l0.",k,"output76,l0.",k,"output77,l0.",k,"output78,l0.",k,"output79,l0.",k,"output80,l0.",k,"output81,l0.",k,"output82,l0.",k,"output83,l0.",k,"output84,l0.",k,"output85,l0.",k,"output86,l0.",k,"output87,l0.",k,"output88,l0.",k,"output89,l0.",k,"output90,l0.",k,"output91,l0.",k,"output92,l0.",k,"output93,l0.",k,"output94,l0.",k,"output95,l0.",k,"output96,l0.",k,"output97,l0.",k,"output98)",sep="")))
}

###l1###

for (i in 1:98) {
  for (k in dvlist) {
    eval(parse(text=paste("l1.",k,"output",i,"<-blank.mat",sep="")))
    eval(parse(text=paste("l1.",k,"output",i,"$modelnum<-",i,sep="")))
    eval(parse(text=paste("l1.",k,"output",i,"$lag<-1",sep=""))) 
  }
}

for (k in dvlist) {
  for (j in 16:51) {
    data<-subset(stable,year==sum(c(1959,j)))
    eval(parse(text=paste("data$publicgood<-data$",k,sep="")))
    try(model1 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model2 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model3 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model4 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model5 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model6 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model7 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model8 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model9 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model10 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model11 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model12 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model13 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model14 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model15 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model16 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model17 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model18 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model19 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model20 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model21 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model22 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model23 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + musl80 + cath80+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model24 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + musl80 + cath80+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model25 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model26 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + pop14.l1 + pop65.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model27 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + pop14.l1 + pop65.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model28 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model29 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model30 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model31 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model32 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model33 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model34 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model35 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model36 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model37 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model38 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model39 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ musl80 + cath80+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model40 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ musl80 + cath80+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model41 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ pop14.l1 + pop65.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model42 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model43 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ pop14.l1 + pop65.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model44 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model45 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model46 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model47 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model48 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model49 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ musl80 + cath80+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model50 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ musl80 + cath80+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model51 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ pop14.l1 + pop65.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model52 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model53 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ pop14.l1 + pop65.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model54 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model55 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model56 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model57 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l1 + pop65.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model58 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model59 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l1 + pop65.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model60 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + musl80 + cath80+ pop14.l1 + pop65.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model61 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + musl80 + cath80+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model62 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + musl80 + cath80+ pop14.l1 + pop65.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model63 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + pop14.l1 + pop65.l1+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model64 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model65 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model66 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model67 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model68 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model69 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ musl80 + cath80+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model70 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ musl80 + cath80+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model71 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ pop14.l1 + pop65.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model72 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model73 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ popdens.l1+ pop14.l1 + pop65.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model74 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model75 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model76 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model77 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l1 + pop65.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model78 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model79 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l1 + pop65.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model80 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ musl80 + cath80+ pop14.l1 + pop65.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model81 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ musl80 + cath80+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model82 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ musl80 + cath80+ pop14.l1 + pop65.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model83 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + area+ pop14.l1 + pop65.l1+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model84 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model85 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l1 + pop65.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model86 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l1 + pop65.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model87 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model88 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l1 + pop65.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model89 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ musl80 + cath80+ pop14.l1 + pop65.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model90 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ musl80 + cath80+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model91 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ musl80 + cath80+ pop14.l1 + pop65.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model92 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ pop14.l1 + pop65.l1+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model93 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l1 + pop65.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model94 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model95 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + popdens.l1+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model96 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l1 + pop65.l1+ odapercgni.l1, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model97 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l1 + pop65.l1+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model98 <- zelig(publicgood ~ polity2.l1 + log(gdppc.l1) + urb.pertotpop.l1 + poptot.l1 + musl80 + cath80+ pop14.l1 + pop65.l1+ odapercgni.l1+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)        
    for (i in 1:98) {
      try(eval(parse(text=paste("l1.",k,"output",i,"[j,2:5]<-summary(model",i,")$coefficients[2,c(1,2,3,4)]",sep=""))), silent=TRUE)
      try(eval(parse(text=paste("l1.",k,"output",i,"[j,8]<-summary(model",i,")$df[2]+summary(model",i,")$df[1]",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("l1.",k,"output",i,"[j,10]<-summary(model",i,")$adj.r.squared",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("rm(model",i,")",sep=""))), silent=TRUE)
    }
  }
}

for (k in dvlist) {
  eval(parse(text=paste("full.l1.",k,"output<-rbind(l1.",k,"output1,l1.",k,"output2,l1.",k,"output3,l1.",k,"output4,l1.",k,"output5,l1.",k,"output6,l1.",k,"output7,l1.",k,"output8,l1.",k,"output9,l1.",k,"output10,l1.",k,"output11,l1.",k,"output12,l1.",k,"output13,l1.",k,"output14,l1.",k,"output15,l1.",k,"output16,l1.",k,"output17,l1.",k,"output18,l1.",k,"output19,l1.",k,"output20,l1.",k,"output21,l1.",k,"output22,l1.",k,"output23,l1.",k,"output24,l1.",k,"output25,l1.",k,"output26,l1.",k,"output27,l1.",k,"output28,l1.",k,"output29,l1.",k,"output30,l1.",k,"output31,l1.",k,"output32,l1.",k,"output33,l1.",k,"output34,l1.",k,"output35,l1.",k,"output36,l1.",k,"output37,l1.",k,"output38,l1.",k,"output39,l1.",k,"output40,l1.",k,"output41,l1.",k,"output42,l1.",k,"output43,l1.",k,"output44,l1.",k,"output45,l1.",k,"output46,l1.",k,"output47,l1.",k,"output48,l1.",k,"output49,l1.",k,"output50,l1.",k,"output51,l1.",k,"output52,l1.",k,"output53,l1.",k,"output54,l1.",k,"output55,l1.",k,"output56,l1.",k,"output57,l1.",k,"output58,l1.",k,"output59,l1.",k,"output60,l1.",k,"output61,l1.",k,"output62,l1.",k,"output63,l1.",k,"output64,l1.",k,"output65,l1.",k,"output66,l1.",k,"output67,l1.",k,"output68,l1.",k,"output69,l1.",k,"output70,l1.",k,"output71,l1.",k,"output72,l1.",k,"output73,l1.",k,"output74,l1.",k,"output75,l1.",k,"output76,l1.",k,"output77,l1.",k,"output78,l1.",k,"output79,l1.",k,"output80,l1.",k,"output81,l1.",k,"output82,l1.",k,"output83,l1.",k,"output84,l1.",k,"output85,l1.",k,"output86,l1.",k,"output87,l1.",k,"output88,l1.",k,"output89,l1.",k,"output90,l1.",k,"output91,l1.",k,"output92,l1.",k,"output93,l1.",k,"output94,l1.",k,"output95,l1.",k,"output96,l1.",k,"output97,l1.",k,"output98)",sep="")))
}

###l2####

for (i in 1:98) {
  for (k in dvlist) {
    eval(parse(text=paste("l2.",k,"output",i,"<-blank.mat",sep="")))
    eval(parse(text=paste("l2.",k,"output",i,"$modelnum<-",i,sep="")))
    eval(parse(text=paste("l2.",k,"output",i,"$lag<-2",sep=""))) 
  }
}

for (k in dvlist) {
  for (j in 16:51) {
    data<-subset(stable,year==sum(c(1959,j)))
    eval(parse(text=paste("data$publicgood<-data$",k,sep="")))
    try(model1 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model2 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model3 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model4 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model5 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model6 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model7 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model8 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model9 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model10 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model11 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model12 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model13 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model14 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model15 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model16 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model17 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model18 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model19 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model20 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model21 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model22 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model23 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + musl80 + cath80+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model24 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + musl80 + cath80+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model25 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model26 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + pop14.l2 + pop65.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model27 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + pop14.l2 + pop65.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model28 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model29 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model30 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model31 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model32 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model33 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model34 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model35 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model36 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model37 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model38 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model39 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ musl80 + cath80+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model40 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ musl80 + cath80+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model41 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ pop14.l2 + pop65.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model42 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model43 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ pop14.l2 + pop65.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model44 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model45 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model46 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model47 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model48 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model49 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ musl80 + cath80+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model50 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ musl80 + cath80+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model51 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ pop14.l2 + pop65.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model52 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model53 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ pop14.l2 + pop65.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model54 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model55 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model56 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model57 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l2 + pop65.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model58 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model59 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l2 + pop65.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model60 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + musl80 + cath80+ pop14.l2 + pop65.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model61 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + musl80 + cath80+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model62 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + musl80 + cath80+ pop14.l2 + pop65.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model63 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + pop14.l2 + pop65.l2+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model64 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model65 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model66 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model67 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model68 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model69 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ musl80 + cath80+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model70 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ musl80 + cath80+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model71 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ pop14.l2 + pop65.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model72 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model73 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ popdens.l2+ pop14.l2 + pop65.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model74 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model75 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model76 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model77 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l2 + pop65.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model78 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model79 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l2 + pop65.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model80 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ musl80 + cath80+ pop14.l2 + pop65.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model81 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ musl80 + cath80+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model82 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ musl80 + cath80+ pop14.l2 + pop65.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model83 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + area+ pop14.l2 + pop65.l2+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model84 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model85 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l2 + pop65.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model86 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l2 + pop65.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model87 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model88 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l2 + pop65.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model89 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ musl80 + cath80+ pop14.l2 + pop65.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model90 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ musl80 + cath80+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model91 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ musl80 + cath80+ pop14.l2 + pop65.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model92 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ pop14.l2 + pop65.l2+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model93 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l2 + pop65.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model94 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model95 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + popdens.l2+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model96 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l2 + pop65.l2+ odapercgni.l2, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model97 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l2 + pop65.l2+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model98 <- zelig(publicgood ~ polity2.l2 + log(gdppc.l2) + urb.pertotpop.l2 + poptot.l2 + musl80 + cath80+ pop14.l2 + pop65.l2+ odapercgni.l2+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)        
    for (i in 1:98) {
      try(eval(parse(text=paste("l2.",k,"output",i,"[j,2:5]<-summary(model",i,")$coefficients[2,c(1,2,3,4)]",sep=""))), silent=TRUE)
      try(eval(parse(text=paste("l2.",k,"output",i,"[j,8]<-summary(model",i,")$df[2]+summary(model",i,")$df[1]",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("l2.",k,"output",i,"[j,10]<-summary(model",i,")$adj.r.squared",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("rm(model",i,")",sep=""))), silent=TRUE)
    }
  }
}

for (k in dvlist) {
  eval(parse(text=paste("full.l2.",k,"output<-rbind(l2.",k,"output1,l2.",k,"output2,l2.",k,"output3,l2.",k,"output4,l2.",k,"output5,l2.",k,"output6,l2.",k,"output7,l2.",k,"output8,l2.",k,"output9,l2.",k,"output10,l2.",k,"output11,l2.",k,"output12,l2.",k,"output13,l2.",k,"output14,l2.",k,"output15,l2.",k,"output16,l2.",k,"output17,l2.",k,"output18,l2.",k,"output19,l2.",k,"output20,l2.",k,"output21,l2.",k,"output22,l2.",k,"output23,l2.",k,"output24,l2.",k,"output25,l2.",k,"output26,l2.",k,"output27,l2.",k,"output28,l2.",k,"output29,l2.",k,"output30,l2.",k,"output31,l2.",k,"output32,l2.",k,"output33,l2.",k,"output34,l2.",k,"output35,l2.",k,"output36,l2.",k,"output37,l2.",k,"output38,l2.",k,"output39,l2.",k,"output40,l2.",k,"output41,l2.",k,"output42,l2.",k,"output43,l2.",k,"output44,l2.",k,"output45,l2.",k,"output46,l2.",k,"output47,l2.",k,"output48,l2.",k,"output49,l2.",k,"output50,l2.",k,"output51,l2.",k,"output52,l2.",k,"output53,l2.",k,"output54,l2.",k,"output55,l2.",k,"output56,l2.",k,"output57,l2.",k,"output58,l2.",k,"output59,l2.",k,"output60,l2.",k,"output61,l2.",k,"output62,l2.",k,"output63,l2.",k,"output64,l2.",k,"output65,l2.",k,"output66,l2.",k,"output67,l2.",k,"output68,l2.",k,"output69,l2.",k,"output70,l2.",k,"output71,l2.",k,"output72,l2.",k,"output73,l2.",k,"output74,l2.",k,"output75,l2.",k,"output76,l2.",k,"output77,l2.",k,"output78,l2.",k,"output79,l2.",k,"output80,l2.",k,"output81,l2.",k,"output82,l2.",k,"output83,l2.",k,"output84,l2.",k,"output85,l2.",k,"output86,l2.",k,"output87,l2.",k,"output88,l2.",k,"output89,l2.",k,"output90,l2.",k,"output91,l2.",k,"output92,l2.",k,"output93,l2.",k,"output94,l2.",k,"output95,l2.",k,"output96,l2.",k,"output97,l2.",k,"output98)",sep="")))
}

for (i in 1:98) {
  for (k in dvlist) {
    eval(parse(text=paste("l3.",k,"output",i,"<-blank.mat",sep="")))
    eval(parse(text=paste("l3.",k,"output",i,"$modelnum<-",i,sep="")))
    eval(parse(text=paste("l3.",k,"output",i,"$lag<-3",sep=""))) 
  }
}

for (k in dvlist) {
  for (j in 16:51) {
    data<-subset(stable,year==sum(c(1959,j)))
    eval(parse(text=paste("data$publicgood<-data$",k,sep="")))
    try(model1 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model2 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model3 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model4 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model5 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model6 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model7 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model8 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model9 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model10 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model11 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model12 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model13 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model14 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model15 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model16 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model17 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model18 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model19 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model20 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model21 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model22 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model23 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + musl80 + cath80+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model24 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + musl80 + cath80+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model25 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model26 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + pop14.l3 + pop65.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model27 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + pop14.l3 + pop65.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model28 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model29 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model30 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model31 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model32 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model33 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model34 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model35 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model36 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model37 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model38 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model39 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ musl80 + cath80+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model40 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ musl80 + cath80+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model41 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ pop14.l3 + pop65.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model42 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model43 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ pop14.l3 + pop65.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model44 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model45 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model46 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model47 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model48 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model49 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ musl80 + cath80+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model50 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ musl80 + cath80+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model51 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ pop14.l3 + pop65.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model52 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model53 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ pop14.l3 + pop65.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model54 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model55 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model56 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model57 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l3 + pop65.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model58 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model59 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l3 + pop65.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model60 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + musl80 + cath80+ pop14.l3 + pop65.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model61 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + musl80 + cath80+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model62 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + musl80 + cath80+ pop14.l3 + pop65.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model63 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + pop14.l3 + pop65.l3+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model64 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model65 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model66 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model67 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model68 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model69 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ musl80 + cath80+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model70 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ musl80 + cath80+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model71 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ pop14.l3 + pop65.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model72 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model73 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ popdens.l3+ pop14.l3 + pop65.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model74 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model75 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model76 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model77 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l3 + pop65.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model78 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model79 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l3 + pop65.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model80 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ musl80 + cath80+ pop14.l3 + pop65.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model81 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ musl80 + cath80+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model82 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ musl80 + cath80+ pop14.l3 + pop65.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model83 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + area+ pop14.l3 + pop65.l3+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model84 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model85 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l3 + pop65.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model86 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l3 + pop65.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model87 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model88 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l3 + pop65.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model89 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ musl80 + cath80+ pop14.l3 + pop65.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model90 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ musl80 + cath80+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model91 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ musl80 + cath80+ pop14.l3 + pop65.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model92 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ pop14.l3 + pop65.l3+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model93 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l3 + pop65.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model94 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model95 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + popdens.l3+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model96 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l3 + pop65.l3+ odapercgni.l3, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model97 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l3 + pop65.l3+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model98 <- zelig(publicgood ~ polity2.l3 + log(gdppc.l3) + urb.pertotpop.l3 + poptot.l3 + musl80 + cath80+ pop14.l3 + pop65.l3+ odapercgni.l3+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)        
    for (i in 1:98) {
      try(eval(parse(text=paste("l3.",k,"output",i,"[j,2:5]<-summary(model",i,")$coefficients[2,c(1,2,3,4)]",sep=""))), silent=TRUE)
      try(eval(parse(text=paste("l3.",k,"output",i,"[j,8]<-summary(model",i,")$df[2]+summary(model",i,")$df[1]",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("l3.",k,"output",i,"[j,10]<-summary(model",i,")$adj.r.squared",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("rm(model",i,")",sep=""))), silent=TRUE)
    }
  }
}

for (k in dvlist) {
  eval(parse(text=paste("full.l3.",k,"output<-rbind(l3.",k,"output1,l3.",k,"output2,l3.",k,"output3,l3.",k,"output4,l3.",k,"output5,l3.",k,"output6,l3.",k,"output7,l3.",k,"output8,l3.",k,"output9,l3.",k,"output10,l3.",k,"output11,l3.",k,"output12,l3.",k,"output13,l3.",k,"output14,l3.",k,"output15,l3.",k,"output16,l3.",k,"output17,l3.",k,"output18,l3.",k,"output19,l3.",k,"output20,l3.",k,"output21,l3.",k,"output22,l3.",k,"output23,l3.",k,"output24,l3.",k,"output25,l3.",k,"output26,l3.",k,"output27,l3.",k,"output28,l3.",k,"output29,l3.",k,"output30,l3.",k,"output31,l3.",k,"output32,l3.",k,"output33,l3.",k,"output34,l3.",k,"output35,l3.",k,"output36,l3.",k,"output37,l3.",k,"output38,l3.",k,"output39,l3.",k,"output40,l3.",k,"output41,l3.",k,"output42,l3.",k,"output43,l3.",k,"output44,l3.",k,"output45,l3.",k,"output46,l3.",k,"output47,l3.",k,"output48,l3.",k,"output49,l3.",k,"output50,l3.",k,"output51,l3.",k,"output52,l3.",k,"output53,l3.",k,"output54,l3.",k,"output55,l3.",k,"output56,l3.",k,"output57,l3.",k,"output58,l3.",k,"output59,l3.",k,"output60,l3.",k,"output61,l3.",k,"output62,l3.",k,"output63,l3.",k,"output64,l3.",k,"output65,l3.",k,"output66,l3.",k,"output67,l3.",k,"output68,l3.",k,"output69,l3.",k,"output70,l3.",k,"output71,l3.",k,"output72,l3.",k,"output73,l3.",k,"output74,l3.",k,"output75,l3.",k,"output76,l3.",k,"output77,l3.",k,"output78,l3.",k,"output79,l3.",k,"output80,l3.",k,"output81,l3.",k,"output82,l3.",k,"output83,l3.",k,"output84,l3.",k,"output85,l3.",k,"output86,l3.",k,"output87,l3.",k,"output88,l3.",k,"output89,l3.",k,"output90,l3.",k,"output91,l3.",k,"output92,l3.",k,"output93,l3.",k,"output94,l3.",k,"output95,l3.",k,"output96,l3.",k,"output97,l3.",k,"output98)",sep="")))
}

for (i in 1:98) {
  for (k in dvlist) {
    eval(parse(text=paste("l4.",k,"output",i,"<-blank.mat",sep="")))
    eval(parse(text=paste("l4.",k,"output",i,"$modelnum<-",i,sep="")))
    eval(parse(text=paste("l4.",k,"output",i,"$lag<-4",sep=""))) 
  }
}

for (k in dvlist) {
  for (j in 16:51) {
    data<-subset(stable,year==sum(c(1959,j)))
    eval(parse(text=paste("data$publicgood<-data$",k,sep="")))
    try(model1 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model2 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model3 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model4 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model5 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model6 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model7 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model8 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model9 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model10 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model11 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model12 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model13 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model14 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model15 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model16 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model17 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model18 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model19 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model20 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model21 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model22 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model23 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + musl80 + cath80+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model24 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + musl80 + cath80+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model25 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model26 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + pop14.l4 + pop65.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model27 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + pop14.l4 + pop65.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model28 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model29 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model30 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model31 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model32 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model33 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model34 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model35 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model36 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model37 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model38 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model39 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ musl80 + cath80+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model40 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ musl80 + cath80+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model41 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ pop14.l4 + pop65.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model42 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model43 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ pop14.l4 + pop65.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model44 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model45 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model46 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model47 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model48 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model49 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ musl80 + cath80+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model50 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ musl80 + cath80+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model51 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ pop14.l4 + pop65.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model52 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model53 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ pop14.l4 + pop65.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model54 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model55 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model56 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model57 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l4 + pop65.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model58 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model59 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l4 + pop65.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model60 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + musl80 + cath80+ pop14.l4 + pop65.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model61 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + musl80 + cath80+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model62 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + musl80 + cath80+ pop14.l4 + pop65.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model63 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + pop14.l4 + pop65.l4+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model64 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model65 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model66 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model67 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model68 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model69 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ musl80 + cath80+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model70 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ musl80 + cath80+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model71 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ pop14.l4 + pop65.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model72 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model73 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ popdens.l4+ pop14.l4 + pop65.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model74 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model75 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model76 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model77 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l4 + pop65.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model78 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model79 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l4 + pop65.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model80 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ musl80 + cath80+ pop14.l4 + pop65.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model81 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ musl80 + cath80+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model82 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ musl80 + cath80+ pop14.l4 + pop65.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model83 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + area+ pop14.l4 + pop65.l4+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model84 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model85 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l4 + pop65.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model86 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l4 + pop65.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model87 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model88 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l4 + pop65.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model89 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ musl80 + cath80+ pop14.l4 + pop65.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model90 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ musl80 + cath80+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model91 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ musl80 + cath80+ pop14.l4 + pop65.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model92 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ pop14.l4 + pop65.l4+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model93 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l4 + pop65.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model94 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model95 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + popdens.l4+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model96 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l4 + pop65.l4+ odapercgni.l4, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model97 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l4 + pop65.l4+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model98 <- zelig(publicgood ~ polity2.l4 + log(gdppc.l4) + urb.pertotpop.l4 + poptot.l4 + musl80 + cath80+ pop14.l4 + pop65.l4+ odapercgni.l4+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)        
    for (i in 1:98) {
      try(eval(parse(text=paste("l4.",k,"output",i,"[j,2:5]<-summary(model",i,")$coefficients[2,c(1,2,3,4)]",sep=""))), silent=TRUE)
      try(eval(parse(text=paste("l4.",k,"output",i,"[j,8]<-summary(model",i,")$df[2]+summary(model",i,")$df[1]",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("l4.",k,"output",i,"[j,10]<-summary(model",i,")$adj.r.squared",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("rm(model",i,")",sep=""))), silent=TRUE)
    }
  }
}

for (k in dvlist) {
  eval(parse(text=paste("full.l4.",k,"output<-rbind(l4.",k,"output1,l4.",k,"output2,l4.",k,"output3,l4.",k,"output4,l4.",k,"output5,l4.",k,"output6,l4.",k,"output7,l4.",k,"output8,l4.",k,"output9,l4.",k,"output10,l4.",k,"output11,l4.",k,"output12,l4.",k,"output13,l4.",k,"output14,l4.",k,"output15,l4.",k,"output16,l4.",k,"output17,l4.",k,"output18,l4.",k,"output19,l4.",k,"output20,l4.",k,"output21,l4.",k,"output22,l4.",k,"output23,l4.",k,"output24,l4.",k,"output25,l4.",k,"output26,l4.",k,"output27,l4.",k,"output28,l4.",k,"output29,l4.",k,"output30,l4.",k,"output31,l4.",k,"output32,l4.",k,"output33,l4.",k,"output34,l4.",k,"output35,l4.",k,"output36,l4.",k,"output37,l4.",k,"output38,l4.",k,"output39,l4.",k,"output40,l4.",k,"output41,l4.",k,"output42,l4.",k,"output43,l4.",k,"output44,l4.",k,"output45,l4.",k,"output46,l4.",k,"output47,l4.",k,"output48,l4.",k,"output49,l4.",k,"output50,l4.",k,"output51,l4.",k,"output52,l4.",k,"output53,l4.",k,"output54,l4.",k,"output55,l4.",k,"output56,l4.",k,"output57,l4.",k,"output58,l4.",k,"output59,l4.",k,"output60,l4.",k,"output61,l4.",k,"output62,l4.",k,"output63,l4.",k,"output64,l4.",k,"output65,l4.",k,"output66,l4.",k,"output67,l4.",k,"output68,l4.",k,"output69,l4.",k,"output70,l4.",k,"output71,l4.",k,"output72,l4.",k,"output73,l4.",k,"output74,l4.",k,"output75,l4.",k,"output76,l4.",k,"output77,l4.",k,"output78,l4.",k,"output79,l4.",k,"output80,l4.",k,"output81,l4.",k,"output82,l4.",k,"output83,l4.",k,"output84,l4.",k,"output85,l4.",k,"output86,l4.",k,"output87,l4.",k,"output88,l4.",k,"output89,l4.",k,"output90,l4.",k,"output91,l4.",k,"output92,l4.",k,"output93,l4.",k,"output94,l4.",k,"output95,l4.",k,"output96,l4.",k,"output97,l4.",k,"output98)",sep="")))
}

for (i in 1:98) {
  for (k in dvlist) {
    eval(parse(text=paste("l5.",k,"output",i,"<-blank.mat",sep="")))
    eval(parse(text=paste("l5.",k,"output",i,"$modelnum<-",i,sep="")))
    eval(parse(text=paste("l5.",k,"output",i,"$lag<-5",sep=""))) 
  }
}

for (k in dvlist) {
  for (j in 16:51) {
    data<-subset(stable,year==sum(c(1959,j)))
    eval(parse(text=paste("data$publicgood<-data$",k,sep="")))
    try(model1 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model2 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model3 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model4 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model5 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model6 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model7 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model8 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model9 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model10 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model11 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model12 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model13 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model14 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model15 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model16 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model17 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model18 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model19 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model20 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model21 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model22 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model23 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + musl80 + cath80+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model24 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + musl80 + cath80+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model25 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model26 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + pop14.l5 + pop65.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model27 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + pop14.l5 + pop65.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model28 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model29 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model30 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model31 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model32 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model33 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model34 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model35 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model36 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model37 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model38 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model39 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ musl80 + cath80+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model40 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ musl80 + cath80+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model41 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ pop14.l5 + pop65.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model42 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model43 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ pop14.l5 + pop65.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model44 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model45 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model46 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model47 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model48 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model49 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ musl80 + cath80+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model50 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ musl80 + cath80+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model51 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ pop14.l5 + pop65.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model52 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model53 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ pop14.l5 + pop65.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model54 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model55 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model56 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model57 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l5 + pop65.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model58 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model59 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l5 + pop65.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model60 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + musl80 + cath80+ pop14.l5 + pop65.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model61 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + musl80 + cath80+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model62 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + musl80 + cath80+ pop14.l5 + pop65.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model63 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + pop14.l5 + pop65.l5+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model64 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model65 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model66 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model67 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model68 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model69 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ musl80 + cath80+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model70 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ musl80 + cath80+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model71 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ pop14.l5 + pop65.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model72 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model73 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ popdens.l5+ pop14.l5 + pop65.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model74 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model75 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model76 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model77 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l5 + pop65.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model78 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model79 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l5 + pop65.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model80 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ musl80 + cath80+ pop14.l5 + pop65.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model81 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ musl80 + cath80+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model82 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ musl80 + cath80+ pop14.l5 + pop65.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model83 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + area+ pop14.l5 + pop65.l5+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model84 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model85 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l5 + pop65.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model86 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l5 + pop65.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model87 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model88 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ pop14.l5 + pop65.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model89 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ musl80 + cath80+ pop14.l5 + pop65.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model90 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ musl80 + cath80+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model91 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ musl80 + cath80+ pop14.l5 + pop65.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model92 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ pop14.l5 + pop65.l5+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model93 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l5 + pop65.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model94 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model95 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + popdens.l5+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model96 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14.l5 + pop65.l5+ odapercgni.l5, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model97 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + africa + asia + ceurope + meast + nam + sam + scan+ pop14.l5 + pop65.l5+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model98 <- zelig(publicgood ~ polity2.l5 + log(gdppc.l5) + urb.pertotpop.l5 + poptot.l5 + musl80 + cath80+ pop14.l5 + pop65.l5+ odapercgni.l5+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)        
    for (i in 1:98) {
      try(eval(parse(text=paste("l5.",k,"output",i,"[j,2:5]<-summary(model",i,")$coefficients[2,c(1,2,3,4)]",sep=""))), silent=TRUE)
      try(eval(parse(text=paste("l5.",k,"output",i,"[j,8]<-summary(model",i,")$df[2]+summary(model",i,")$df[1]",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("l5.",k,"output",i,"[j,10]<-summary(model",i,")$adj.r.squared",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("rm(model",i,")",sep=""))), silent=TRUE)
    }
  }
}

for (k in dvlist) {
  eval(parse(text=paste("full.l5.",k,"output<-rbind(l5.",k,"output1,l5.",k,"output2,l5.",k,"output3,l5.",k,"output4,l5.",k,"output5,l5.",k,"output6,l5.",k,"output7,l5.",k,"output8,l5.",k,"output9,l5.",k,"output10,l5.",k,"output11,l5.",k,"output12,l5.",k,"output13,l5.",k,"output14,l5.",k,"output15,l5.",k,"output16,l5.",k,"output17,l5.",k,"output18,l5.",k,"output19,l5.",k,"output20,l5.",k,"output21,l5.",k,"output22,l5.",k,"output23,l5.",k,"output24,l5.",k,"output25,l5.",k,"output26,l5.",k,"output27,l5.",k,"output28,l5.",k,"output29,l5.",k,"output30,l5.",k,"output31,l5.",k,"output32,l5.",k,"output33,l5.",k,"output34,l5.",k,"output35,l5.",k,"output36,l5.",k,"output37,l5.",k,"output38,l5.",k,"output39,l5.",k,"output40,l5.",k,"output41,l5.",k,"output42,l5.",k,"output43,l5.",k,"output44,l5.",k,"output45,l5.",k,"output46,l5.",k,"output47,l5.",k,"output48,l5.",k,"output49,l5.",k,"output50,l5.",k,"output51,l5.",k,"output52,l5.",k,"output53,l5.",k,"output54,l5.",k,"output55,l5.",k,"output56,l5.",k,"output57,l5.",k,"output58,l5.",k,"output59,l5.",k,"output60,l5.",k,"output61,l5.",k,"output62,l5.",k,"output63,l5.",k,"output64,l5.",k,"output65,l5.",k,"output66,l5.",k,"output67,l5.",k,"output68,l5.",k,"output69,l5.",k,"output70,l5.",k,"output71,l5.",k,"output72,l5.",k,"output73,l5.",k,"output74,l5.",k,"output75,l5.",k,"output76,l5.",k,"output77,l5.",k,"output78,l5.",k,"output79,l5.",k,"output80,l5.",k,"output81,l5.",k,"output82,l5.",k,"output83,l5.",k,"output84,l5.",k,"output85,l5.",k,"output86,l5.",k,"output87,l5.",k,"output88,l5.",k,"output89,l5.",k,"output90,l5.",k,"output91,l5.",k,"output92,l5.",k,"output93,l5.",k,"output94,l5.",k,"output95,l5.",k,"output96,l5.",k,"output97,l5.",k,"output98)",sep="")))
  eval(parse(text=paste("full.l5.",k,"output$lag=5",sep="")))
}

###CREATING FINAL OUTPUT###

for (k in dvlist) {
  eval(parse(text=paste(k,".polity2.finaloutput<-rbind(full.l0.",k,"output, full.l1.",k,"output, full.l2.",k,"output, full.l3.",k,"output, full.l4.",k,"output, full.l5.",k,"output)",sep="")))
}

fh.civilliberties.polity2.finaloutput$dv="fh.civilliberties"
fh.press.polity2.finaloutput$dv="fh.press"
deathrate.polity2.finaloutput$dv="deathrate"
infantmortrate.polity2.finaloutput$dv="infantmortrate"
immunizdpt.polity2.finaloutput$dv="immunizdpt"
measles.polity2.finaloutput$dv="measles"
water.tot.polity2.finaloutput$dv="water.tot"
pupilsteachers.prim.rat.polity2.finaloutput$dv="pupilsteachers.prim.rat"
pupilsteachers.sec.rat.polity2.finaloutput$dv="pupilsteachers.sec.rat"
enrollmentrate.sec.polity2.finaloutput$dv="enrollmentrate.sec"
enrollmentrate.prim.polity2.finaloutput$dv="enrollmentrate.prim"
primcomp.rate.polity2.finaloutput$dv="primcomp.rate"
sanitation.tot.polity2.finaloutput$dv="sanitation.tot"
physicians.polity2.finaloutput$dv="physicians"
beds.polity2.finaloutput$dv="beds"
lifeexpect.polity2.finaloutput$dv="lifeexpect"

polity2.finaloutput.combined<-rbind(fh.civilliberties.polity2.finaloutput, fh.press.polity2.finaloutput, deathrate.polity2.finaloutput, infantmortrate.polity2.finaloutput, immunizdpt.polity2.finaloutput, measles.polity2.finaloutput, water.tot.polity2.finaloutput, pupilsteachers.prim.rat.polity2.finaloutput, pupilsteachers.sec.rat.polity2.finaloutput, enrollmentrate.sec.polity2.finaloutput, enrollmentrate.prim.polity2.finaloutput, primcomp.rate.polity2.finaloutput, sanitation.tot.polity2.finaloutput, physicians.polity2.finaloutput, beds.polity2.finaloutput, lifeexpect.polity2.finaloutput)

write.dta(polity2.finaloutput.combined,"polity2.finaloutput.combined.dta")



###CREATING KEEP FILTER###

democracy.finaloutput.combined <- read.dta("democracy.finaloutput.combined.dta", convert.underscore = TRUE) 

democracy.finaloutput.combined<-subset(democracy.finaloutput.combined,democracy.finaloutput.combined$year>1974)
democracy.finaloutput.combined$keep<-1
democracy.finaloutput.combined$keep[(democracy.finaloutput.combined$n<80)==TRUE]<-0
democracy.finaloutput.combined$keep[is.na(democracy.finaloutput.combined$n)==TRUE]<-0
democracy.finaloutput.combined$keep[is.na(democracy.finaloutput.combined$se)==TRUE]<-0

democracy.finaloutput.combined$keep100<-1
democracy.finaloutput.combined$keep100[(democracy.finaloutput.combined$n<100)==TRUE]<-0
democracy.finaloutput.combined$keep100[is.na(democracy.finaloutput.combined$n)==TRUE]<-0
democracy.finaloutput.combined$keep100[is.na(democracy.finaloutput.combined$se)==TRUE]<-0

democracy.finaloutput.combined$keep120<-1
democracy.finaloutput.combined$keep120[(democracy.finaloutput.combined$n<120)==TRUE]<-0
democracy.finaloutput.combined$keep120[is.na(democracy.finaloutput.combined$n)==TRUE]<-0
democracy.finaloutput.combined$keep120[is.na(democracy.finaloutput.combined$se)==TRUE]<-0

democracy.finaloutput.combined$keepfull<-1
democracy.finaloutput.combined$keepfull[is.na(democracy.finaloutput.combined$n)==TRUE]<-0
democracy.finaloutput.combined$keepfull[is.na(democracy.finaloutput.combined$se)==TRUE]<-0

polity2.finaloutput.combined <- read.dta("polity2.finaloutput.combined.dta", convert.underscore = TRUE) 

polity2.finaloutput.combined<-subset(polity2.finaloutput.combined,polity2.finaloutput.combined$year>1974)
polity2.finaloutput.combined$keep<-1
polity2.finaloutput.combined$keep[(polity2.finaloutput.combined$n<80)==TRUE]<-0
polity2.finaloutput.combined$keep[is.na(polity2.finaloutput.combined$n)==TRUE]<-0
polity2.finaloutput.combined$keep[is.na(polity2.finaloutput.combined$se)==TRUE]<-0

polity2.finaloutput.combined$keep100<-1
polity2.finaloutput.combined$keep100[(polity2.finaloutput.combined$n<100)==TRUE]<-0
polity2.finaloutput.combined$keep100[is.na(polity2.finaloutput.combined$n)==TRUE]<-0
polity2.finaloutput.combined$keep100[is.na(polity2.finaloutput.combined$se)==TRUE]<-0

polity2.finaloutput.combined$keep120<-1
polity2.finaloutput.combined$keep120[(polity2.finaloutput.combined$n<120)==TRUE]<-0
polity2.finaloutput.combined$keep120[is.na(polity2.finaloutput.combined$n)==TRUE]<-0
polity2.finaloutput.combined$keep120[is.na(polity2.finaloutput.combined$se)==TRUE]<-0

polity2.finaloutput.combined$keepfull<-1
polity2.finaloutput.combined$keepfull[is.na(polity2.finaloutput.combined$n)==TRUE]<-0
polity2.finaloutput.combined$keepfull[is.na(polity2.finaloutput.combined$se)==TRUE]<-0

write.dta(democracy.finaloutput.combined,"democracy.finaloutput.combined.dta")
write.dta(polity2.finaloutput.combined,"polity2.finaloutput.combined.dta")

###CREATING FIGURES###

##Figure 1a##
pdf("apgp.gsa.cs.democracy.edu.pdf", width=10.5, height=7.65)
par(mfcol=c(2,3))
par(cex.axis=1.5)
par(cex.lab=1.5)
par(cex.main=1.5)

#1. Primary Enrollment Rate#
plot(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="enrollmentrate.prim" & democracy.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Enrollment Rate Primary (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="enrollmentrate.prim" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(prim.enroll)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
points(1.891812865,0,cex=1.45,pch=17,col="red",lwd=2)
points(2.319078947,0,cex=1.45,pch=17,col="red",lwd=2)
points(2.278606965,0,cex=1.45,pch=17,col="red",lwd=2)
legend("topleft", legend=c("Lake & Baum"),col=c("red"), pch=c(17), cex=1.25,bty="n")
legend("topright", legend=c("GWF","Polity"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#2. Pupil Teacher Ratio (Secondary)#
plot(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="pupilsteachers.sec.rat" & democracy.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Pupil Teacher Ratio Secondary (-)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="pupilsteachers.sec.rat" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(sec.pupils)")
abline(v=0, lwd=1)
abline(v=-1.64, lwd=1, lty=2)
text(-2.45,.3,"t=-1.64", cex=1.25)
legend("topleft", legend=c("GWF","Polity"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#3. Secondary Enrollment Rate#
plot(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="enrollmentrate.sec" & democracy.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Enrollment Rate Secondary (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="enrollmentrate.sec" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), col="red", lwd=1.25, pch=0,lty=2)
mtext("(sec.enroll)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
points(4.301470588,0,cex=1.45,pch=17,col="red",lwd=2)
points(1.976821192,0,cex=1.45,pch=17,col="red",lwd=2)
points(3.082644628,0,cex=1.45,pch=17,col="red",lwd=2)
legend("topleft", legend=c("Lake & Baum"),col=c("red"), pch=c(17), cex=1.25,bty="n")
legend("topright", legend=c("GWF","Polity"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#4. Pupil Teacher Ratio (Primary)#
plot(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="pupilsteachers.prim.rat" & democracy.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Pupil Teacher Ratio Primary (-)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="pupilsteachers.prim.rat" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(prim.pupils)")
abline(v=0, lwd=1)
abline(v=-1.64, lwd=1, lty=2)
text(-2.45,.3,"t=-1.64", cex=1.25)
points(-2.787330317,0,cex=1.45,pch=17,col="red",lwd=2)
points(-1.765853659,0,cex=1.45,pch=17,col="red",lwd=2)
points(-3.674698795,0,cex=1.45,pch=17,col="red",lwd=2)
legend("topright", legend=c("Lake & Baum"),col=c("red"), pch=c(17), cex=1.25,bty="n")
legend("topleft", legend=c("GWF","Polity"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#5. Primary Completion Rate#
plot(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="primcomp.rate" & democracy.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Completion Rate Primary (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="primcomp.rate" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(prim.comp)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
legend("topright", legend=c("GWF","Polity"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")
dev.off()

##Figure 1b##
pdf("apgp.gsa.cs.democracy.health.pdf", width=10.5, height=11.5)
par(mfcol=c(3,3))
par(cex.axis=1.5)
par(cex.lab=1.5)
par(cex.main=1.5)

#1. Water Total#
plot(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="water.tot" & democracy.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Water Access (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="water.tot" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(water)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
points(3.46749226,0,cex=1.45,pch=17,col="red",lwd=2)
points(2.884615385,0,cex=1.45,pch=17,col="red",lwd=2)
legend("topleft", legend=c("Lake & Baum"),col=c("red"), pch=c(17), cex=1.25,bty="n")
legend("topright", legend=c("GWF","Polity"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#2. DPT Immunization#
plot(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="immunizdpt" & democracy.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="DPT Immunization (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="immunizdpt" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(dpt.im)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
points(-0.695187166,0,cex=1.45,pch=17,col="red",lwd=2)
points(3.816091954,0,cex=1.45,pch=17,col="red",lwd=2)
legend("topleft", legend=c("Lake & Baum"),col=c("red"), pch=c(17), cex=1.25,bty="n")
legend("topright", legend=c("GWF","Polity"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#3. Infant Mortality Rate#
plot(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="infantmortrate" & democracy.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Infant Mortality Rate (-)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="infantmortrate" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(infmort)")
abline(v=0, lwd=1)
abline(v=-1.64, lwd=1, lty=2)
text(-2.45,.3,"t=-1.64", cex=1.25)
points(-3.807692308,0,cex=1.45,pch=17,col="red",lwd=2)
points(-3.158953722,0,cex=1.45,pch=17,col="red",lwd=2)
points(-2.577319588,0,cex=1.45,pch=17,col="red",lwd=2)
legend("topright", legend=c("Lake & Baum"),col=c("red"), pch=c(17), cex=1.25,bty="n")
legend("topleft", legend=c("GWF","Polity"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#4. Sanitation#
plot(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="sanitation.tot" & democracy.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Sanitation Access (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="sanitation.tot" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(sanitation)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
legend("topleft", legend=c("Lake & Baum"),col=c("red"), pch=c(17), cex=1.25,bty="n")
legend("topright", legend=c("GWF","Polity"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#5. Physicians#
plot(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="physicians" & democracy.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Physicians (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="physicians" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(physicians)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
legend("topleft", legend=c("Lake & Baum"),col=c("red"), pch=c(17), cex=1.25,bty="n")
legend("topright", legend=c("GWF","Polity"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#6. Death Rate#
plot(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="deathrate" & democracy.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Death Rate (-)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="deathrate" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(death)")
abline(v=0, lwd=1)
abline(v=-1.64, lwd=1, lty=2)
text(-2.45,.3,"t=-1.64", cex=1.25)
points(-3.173913043,0,cex=1.45,pch=17,col="red",lwd=2)
points(-2.857142857,0,cex=1.45,pch=17,col="red",lwd=2)
points(-1.966292135,0,cex=1.45,pch=17,col="red",lwd=2)
legend("topright", legend=c("Lake & Baum"),col=c("red"), pch=c(17), cex=1.25,bty="n")
legend("topleft", legend=c("GWF","Polity"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#7. Measles Immunization#
plot(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="measles" & democracy.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Measles Immunization (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="measles" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(measles.im)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
points(-0.498789346,0,cex=1.45,pch=17,col="red",lwd=2)
points(0.962295082,0,cex=1.45,pch=17,col="red",lwd=2)
legend("topleft", legend=c("Lake & Baum"),col=c("red"), pch=c(17), cex=1.25,bty="n")
legend("topright", legend=c("GWF","Polity"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#8. Beds#
plot(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="beds" & democracy.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Beds (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="beds" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(beds)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
legend("topleft", legend=c("Lake & Baum"),col=c("red"), pch=c(17), cex=1.25,bty="n")
legend("topright", legend=c("GWF","Polity"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#9. Life Expectancy#
plot(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="lifeexpect" & democracy.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Life Expectancy (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="lifeexpect" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(lifeexpect)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
points(4.15,0,cex=1.45,pch=17,col="red",lwd=2)
points(3.27,0,cex=1.45,pch=17,col="red",lwd=2)
points(2.26,0,cex=1.45,pch=17,col="red",lwd=2)
legend("topleft", legend=c("Lake & Baum"),col=c("red"), pch=c(17), cex=1.25,bty="n")
legend("topright", legend=c("GWF","Polity"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")
dev.off()

##Figure 2##
pdf("fig2.politics.pdf", width=8.5, height=5)
par(mfcol=c(1,2))
par(cex.axis=1.25)
par(cex.lab=1.25)
par(cex.main=1.25)

#1. Press#
plot(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="fh.press" & democracy.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="FH Press Index (-)", col="darkblue", lwd=1.5, pch=0,xlim=c(-10,4),ylim=c(0,.45))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="fh.press" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
legend("topleft", legend=c("GWF","Polity"),col=c("darkblue","red"), lty=c(1,2), cex=1,bty="n")
mtext("(fh.press)")
abline(v=0, lwd=1)
abline(v=-1.64, lwd=1, lty=2)
text(-3.45,.3,"t=-1.64", cex=1)

#2. Civil Liberaties #
plot(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="fh.civilliberties" & democracy.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="FH Civil Liberties Index (-)", col="darkblue", lwd=1.5, pch=0,xlim=c(-10,4),ylim=c(0,.45))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="fh.civilliberties" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
abline(v=0, lwd=1)
mtext("(fh.civlib)")
legend("topleft", legend=c("GWF","Polity"),col=c("darkblue","red"), lty=c(1,2), cex=1,bty="n")
abline(v=0, lwd=1)
abline(v=-1.64, lwd=1, lty=2)
text(-3.45,.3,"t=-1.64", cex=1)
dev.off()

##Figure 3a##
pdf("fig3a-education.samplesize.pdf", width=10.5, height=7.65)
par(mfcol=c(2,3))
par(cex.axis=1.5)
par(cex.lab=1.5)
par(cex.main=1.5)

#1. Primary Enrollment Rate#
plot(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="enrollmentrate.prim" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Enrollment Rate Primary (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="enrollmentrate.prim" & polity2.finaloutput.combined$keepfull==1],na.rm=TRUE), col="red", lwd=1.5, lty=2)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="enrollmentrate.prim" & polity2.finaloutput.combined$keep100==1],na.rm=TRUE), col="darkgreen", lwd=1.5, lty=4)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="enrollmentrate.prim" & polity2.finaloutput.combined$keep120==1],na.rm=TRUE), col="goldenrod", lwd=1.5, lty=5)
mtext("(prim.enroll)")
legend("topleft", legend=c("All estimates","N 80+","N 100+","N 120+"),col=c("red","darkblue","darkgreen","goldenrod"), lty=c(2,1,4,5), cex=1.25,bty="n")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)

#2. Pupil Teacher Ratio (Secondary)#
plot(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="pupilsteachers.sec.rat" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Pupil Teacher Ratio Secondary (-)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="pupilsteachers.sec.rat" & polity2.finaloutput.combined$keepfull==1],na.rm=TRUE), col="red", lwd=1.5, lty=2)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="pupilsteachers.sec.rat" & polity2.finaloutput.combined$keep100==1],na.rm=TRUE), col="darkgreen", lwd=1.5, lty=4)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="pupilsteachers.sec.rat" & polity2.finaloutput.combined$keep120==1],na.rm=TRUE), col="goldenrod", lwd=1.5, lty=5)
mtext("(sec.pupils)")
legend("topright", legend=c("All estimates","N 80+","N 100+","N 120+"),col=c("red","darkblue","darkgreen","goldenrod"), lty=c(2,1,4,5), cex=1.25,bty="n")
abline(v=0, lwd=1)
abline(v=-1.64, lwd=1, lty=2)
text(-2.45,.3,"t=-1.64", cex=1.25)

#3. Secondary Enrollment Rate#
plot(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="enrollmentrate.sec" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Enrollment Rate Secondary (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="enrollmentrate.sec" & polity2.finaloutput.combined$keepfull==1],na.rm=TRUE), col="red", lwd=1.5, lty=2)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="enrollmentrate.sec" & polity2.finaloutput.combined$keep100==1],na.rm=TRUE), col="darkgreen", lwd=1.5, lty=4)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="enrollmentrate.sec" & polity2.finaloutput.combined$keep120==1],na.rm=TRUE), col="goldenrod", lwd=1.5, lty=5)
mtext("(sec.enroll)")
legend("topleft", legend=c("All estimates","N 80+","N 100+","N 120+"),col=c("red","darkblue","darkgreen","goldenrod"), lty=c(2,1,4,5), cex=1.25,bty="n")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)

#4. Pupil Teacher Ratio (Primary)#
plot(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="pupilsteachers.prim.rat" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Pupil Teacher Ratio Primary (-)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="pupilsteachers.prim.rat" & polity2.finaloutput.combined$keepfull==1],na.rm=TRUE), col="red", lwd=1.5, lty=2)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="pupilsteachers.prim.rat" & polity2.finaloutput.combined$keep100==1],na.rm=TRUE), col="darkgreen", lwd=1.5, lty=4)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="pupilsteachers.prim.rat" & polity2.finaloutput.combined$keep120==1],na.rm=TRUE), col="goldenrod", lwd=1.5, lty=5)
mtext("(prim.pupils)")
legend("topright", legend=c("All estimates","N 80+","N 100+","N 120+"),col=c("red","darkblue","darkgreen","goldenrod"), lty=c(2,1,4,5), cex=1.25,bty="n")
abline(v=0, lwd=1)
abline(v=-1.64, lwd=1, lty=2)
text(-2.45,.3,"t=-1.64", cex=1.25)

#5. Primary Completion Rate#
plot(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="primcomp.rate" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Completion Rate Primary (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="primcomp.rate" & polity2.finaloutput.combined$keepfull==1],na.rm=TRUE), col="red", lwd=1.5, lty=2)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="primcomp.rate" & polity2.finaloutput.combined$keep100==1],na.rm=TRUE), col="darkgreen", lwd=1.5, lty=4)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="primcomp.rate" & polity2.finaloutput.combined$keep120==1],na.rm=TRUE), col="goldenrod", lwd=1.5, lty=5)
mtext("(prim.comp)")
legend("topleft", legend=c("All estimates","N 80+","N 100+","N 120+"),col=c("red","darkblue","darkgreen","goldenrod"), lty=c(2,1,4,5), cex=1.25,bty="n")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
dev.off()

##Figure 3b##
pdf("fig3b-health.samplesize.pdf", width=10.5, height=11.5)
par(mfcol=c(3,3))
par(cex.axis=1.5)
par(cex.lab=1.5)
par(cex.main=1.5)

#1. Water Total#
plot(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="water.tot" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Water Access (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="water.tot" & polity2.finaloutput.combined$keepfull==1],na.rm=TRUE), col="red", lwd=1.5, lty=2)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="water.tot" & polity2.finaloutput.combined$keep100==1],na.rm=TRUE), col="darkgreen", lwd=1.5, lty=4)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="water.tot" & polity2.finaloutput.combined$keep120==1],na.rm=TRUE), col="goldenrod", lwd=1.5, lty=5)
mtext("(water)")
legend("topleft", legend=c("All estimates","N 80+","N 100+","N 120+"),col=c("red","darkblue","darkgreen","goldenrod"), lty=c(2,1,4,5), cex=1.25,bty="n")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)

#2. DPT Immunization#
plot(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="immunizdpt" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="DPT Immunization (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="immunizdpt" & polity2.finaloutput.combined$keepfull==1],na.rm=TRUE), col="red", lwd=1.5, lty=2)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="immunizdpt" & polity2.finaloutput.combined$keep100==1],na.rm=TRUE), col="darkgreen", lwd=1.5, lty=4)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="immunizdpt" & polity2.finaloutput.combined$keep120==1],na.rm=TRUE), col="goldenrod", lwd=1.5, lty=5)
mtext("(dpt.im)")
legend("topleft", legend=c("All estimates","N 80+","N 100+","N 120+"),col=c("red","darkblue","darkgreen","goldenrod"), lty=c(2,1,4,5), cex=1.25,bty="n")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)

#3. Infant Mortality Rate#
plot(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="infantmortrate" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Infant Mortality Rate (-)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="infantmortrate" & polity2.finaloutput.combined$keepfull==1],na.rm=TRUE), col="red", lwd=1.5, lty=2)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="infantmortrate" & polity2.finaloutput.combined$keep100==1],na.rm=TRUE), col="darkgreen", lwd=1.5, lty=4)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="infantmortrate" & polity2.finaloutput.combined$keep120==1],na.rm=TRUE), col="goldenrod", lwd=1.5, lty=5)
mtext("(infmort)")
legend("topleft", legend=c("All estimates","N 80+","N 100+","N 120+"),col=c("red","darkblue","darkgreen","goldenrod"), lty=c(2,1,4,5), cex=1.25,bty="n")
abline(v=0, lwd=1)
abline(v=-1.64, lwd=1, lty=2)
text(-2.45,.3,"t=-1.64", cex=1.25)

#4. Sanitation#
plot(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="sanitation.tot" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Sanitation Access (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="sanitation.tot" & polity2.finaloutput.combined$keepfull==1],na.rm=TRUE), col="red", lwd=1.5, lty=2)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="sanitation.tot" & polity2.finaloutput.combined$keep100==1],na.rm=TRUE), col="darkgreen", lwd=1.5, lty=4)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="sanitation.tot" & polity2.finaloutput.combined$keep120==1],na.rm=TRUE), col="goldenrod", lwd=1.5, lty=5)
mtext("(sanitation)")
legend("topleft", legend=c("All estimates","N 80+","N 100+","N 120+"),col=c("red","darkblue","darkgreen","goldenrod"), lty=c(2,1,4,5), cex=1.25,bty="n")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)

#5. Physicians#
plot(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="physicians" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Physicians (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="physicians" & polity2.finaloutput.combined$keepfull==1],na.rm=TRUE), col="red", lwd=1.5, lty=2)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="physicians" & polity2.finaloutput.combined$keep100==1],na.rm=TRUE), col="darkgreen", lwd=1.5, lty=4)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="physicians" & polity2.finaloutput.combined$keep120==1],na.rm=TRUE), col="goldenrod", lwd=1.5, lty=5)
mtext("(physicians)")
legend("topleft", legend=c("All estimates","N 80+","N 100+","N 120+"),col=c("red","darkblue","darkgreen","goldenrod"), lty=c(2,1,4,5), cex=1.25,bty="n")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)

#6. Death Rate#
plot(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="deathrate" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Death Rate (-)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="deathrate" & polity2.finaloutput.combined$keepfull==1],na.rm=TRUE), col="red", lwd=1.5, lty=2)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="deathrate" & polity2.finaloutput.combined$keep100==1],na.rm=TRUE), col="darkgreen", lwd=1.5, lty=4)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="deathrate" & polity2.finaloutput.combined$keep120==1],na.rm=TRUE), col="goldenrod", lwd=1.5, lty=5)
mtext("(death)")
legend("topleft", legend=c("All estimates","N 80+","N 100+","N 120+"),col=c("red","darkblue","darkgreen","goldenrod"), lty=c(2,1,4,5), cex=1.25,bty="n")
abline(v=0, lwd=1)
abline(v=-1.64, lwd=1, lty=2)
text(-2.45,.3,"t=-1.64", cex=1.25)

#7. Measles Immunization#
plot(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="measles" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Measles Immunization (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="measles" & polity2.finaloutput.combined$keepfull==1],na.rm=TRUE), col="red", lwd=1.5, lty=2)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="measles" & polity2.finaloutput.combined$keep100==1],na.rm=TRUE), col="darkgreen", lwd=1.5, lty=4)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="measles" & polity2.finaloutput.combined$keep120==1],na.rm=TRUE), col="goldenrod", lwd=1.5, lty=5)
mtext("(measles.im)")
legend("topleft", legend=c("All estimates","N 80+","N 100+","N 120+"),col=c("red","darkblue","darkgreen","goldenrod"), lty=c(2,1,4,5), cex=1.25,bty="n")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)

#8. Beds#
plot(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="beds" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Beds (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="beds" & polity2.finaloutput.combined$keepfull==1],na.rm=TRUE), col="red", lwd=1.5, lty=2)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="beds" & polity2.finaloutput.combined$keep100==1],na.rm=TRUE), col="darkgreen", lwd=1.5, lty=4)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="beds" & polity2.finaloutput.combined$keep120==1],na.rm=TRUE), col="goldenrod", lwd=1.5, lty=5)
mtext("(beds)")
legend("topleft", legend=c("All estimates","N 80+","N 100+","N 120+"),col=c("red","darkblue","darkgreen","goldenrod"), lty=c(2,1,4,5), cex=1.25,bty="n")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)

#9. Life Expectancy#
plot(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="lifeexpect" & polity2.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Life Expectancy (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="lifeexpect" & polity2.finaloutput.combined$keepfull==1],na.rm=TRUE), col="red", lwd=1.5, lty=2)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="lifeexpect" & polity2.finaloutput.combined$keep100==1],na.rm=TRUE), col="darkgreen", lwd=1.5, lty=4)
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="lifeexpect" & polity2.finaloutput.combined$keep120==1],na.rm=TRUE), col="goldenrod", lwd=1.5, lty=5)
mtext("(lifeexpect)")
legend("topleft", legend=c("All estimates","N 80+","N 100+","N 120+"),col=c("red","darkblue","darkgreen","goldenrod"), lty=c(2,1,4,5), cex=1.25,bty="n")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
dev.off()



###CALCULATING FINAL STATISTICS FOR TABLE 4###

#immunizdpt#
immunizdpt.democracy.tot.models<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$dv=="immunizdpt"])
immunizdpt.democracy.max.estimate<-max(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="immunizdpt"& democracy.finaloutput.combined$keep==1])
immunizdpt.democracy.min.estimate<-min(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="immunizdpt"& democracy.finaloutput.combined$keep==1])
immunizdpt.democracy.5sig.onesided<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$tstat>1.64 & democracy.finaloutput.combined$dv=="immunizdpt"],na.rm=TRUE)/immunizdpt.democracy.tot.models
immunizdpt.democracy.final.noweight.estimate<-mean(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="immunizdpt"& democracy.finaloutput.combined$keep==1])
immunizdpt.democracy.final.noweight.se<-mean(democracy.finaloutput.combined$se[democracy.finaloutput.combined$dv=="immunizdpt"& democracy.finaloutput.combined$keep==1])
immunizdpt.democracy.final.noweight.tstat<-immunizdpt.democracy.final.noweight.estimate/immunizdpt.democracy.final.noweight.se
immunizdpt.democracy.final.noweight.pvalue<-1-pnorm(immunizdpt.democracy.final.noweight.tstat)
immunizdpt.democracy.cdf.empirical.above0<-sum(democracy.finaloutput.combined$keep[(democracy.finaloutput.combined$estimate>0) & democracy.finaloutput.combined$dv=="immunizdpt"],na.rm=TRUE)/immunizdpt.democracy.tot.models

immunizdpt.democracy.cdf.empirical.above0

immunizdpt.democracy.final.noweight.estimate
immunizdpt.democracy.final.noweight.se
immunizdpt.democracy.final.noweight.pvalue

immunizdpt.democracy.5sig.onesided

immunizdpt.democracy.tot.models

#measles#
measles.democracy.tot.models<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$dv=="measles"])
measles.democracy.max.estimate<-max(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="measles"& democracy.finaloutput.combined$keep==1])
measles.democracy.min.estimate<-min(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="measles"& democracy.finaloutput.combined$keep==1])
measles.democracy.5sig.onesided<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$tstat>1.64 & democracy.finaloutput.combined$dv=="measles"],na.rm=TRUE)/measles.democracy.tot.models
measles.democracy.final.noweight.estimate<-mean(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="measles"& democracy.finaloutput.combined$keep==1])
measles.democracy.final.noweight.se<-mean(democracy.finaloutput.combined$se[democracy.finaloutput.combined$dv=="measles"& democracy.finaloutput.combined$keep==1])
measles.democracy.final.noweight.tstat<-measles.democracy.final.noweight.estimate/measles.democracy.final.noweight.se
measles.democracy.final.noweight.pvalue<-1-pnorm(measles.democracy.final.noweight.tstat)
measles.democracy.cdf.empirical.above0<-sum(democracy.finaloutput.combined$keep[(democracy.finaloutput.combined$estimate>0) & democracy.finaloutput.combined$dv=="measles"],na.rm=TRUE)/measles.democracy.tot.models

measles.democracy.cdf.empirical.above0

measles.democracy.final.noweight.estimate
measles.democracy.final.noweight.se
measles.democracy.final.noweight.pvalue

measles.democracy.5sig.onesided

measles.democracy.tot.models

#water.tot#
water.tot.democracy.tot.models<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$dv=="water.tot"])
water.tot.democracy.max.estimate<-max(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="water.tot"& democracy.finaloutput.combined$keep==1])
water.tot.democracy.min.estimate<-min(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="water.tot"& democracy.finaloutput.combined$keep==1])
water.tot.democracy.5sig.onesided<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$tstat<1.64 & democracy.finaloutput.combined$dv=="water.tot"],na.rm=TRUE)/water.tot.democracy.tot.models
water.tot.democracy.final.noweight.estimate<-mean(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="water.tot"& democracy.finaloutput.combined$keep==1])
water.tot.democracy.final.noweight.se<-mean(democracy.finaloutput.combined$se[democracy.finaloutput.combined$dv=="water.tot"& democracy.finaloutput.combined$keep==1])
water.tot.democracy.final.noweight.tstat<-water.tot.democracy.final.noweight.estimate/water.tot.democracy.final.noweight.se
water.tot.democracy.final.noweight.pvalue<-1-pnorm(water.tot.democracy.final.noweight.tstat)
water.tot.democracy.cdf.empirical.above0<-sum(democracy.finaloutput.combined$keep[(democracy.finaloutput.combined$estimate>0) & democracy.finaloutput.combined$dv=="water.tot"],na.rm=TRUE)/water.tot.democracy.tot.models

water.tot.democracy.cdf.empirical.above0

water.tot.democracy.final.noweight.estimate
water.tot.democracy.final.noweight.se
water.tot.democracy.final.noweight.pvalue

water.tot.democracy.5sig.onesided

water.tot.democracy.tot.models

#infantmortrate#
infantmortrate.democracy.tot.models<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$dv=="infantmortrate"])
infantmortrate.democracy.max.estimate<-max(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="infantmortrate"& democracy.finaloutput.combined$keep==1])
infantmortrate.democracy.min.estimate<-min(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="infantmortrate"& democracy.finaloutput.combined$keep==1])
infantmortrate.democracy.5sig.onesided<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$tstat<(-1.64) & democracy.finaloutput.combined$dv=="infantmortrate"],na.rm=TRUE)/infantmortrate.democracy.tot.models
infantmortrate.democracy.final.noweight.estimate<-mean(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="infantmortrate"& democracy.finaloutput.combined$keep==1])
infantmortrate.democracy.final.noweight.se<-mean(democracy.finaloutput.combined$se[democracy.finaloutput.combined$dv=="infantmortrate"& democracy.finaloutput.combined$keep==1])
infantmortrate.democracy.final.noweight.tstat<-infantmortrate.democracy.final.noweight.estimate/infantmortrate.democracy.final.noweight.se
infantmortrate.democracy.final.noweight.pvalue<-pnorm(infantmortrate.democracy.final.noweight.tstat)
infantmortrate.democracy.cdf.empirical.below0<-sum(democracy.finaloutput.combined$keep[(democracy.finaloutput.combined$estimate<0) & democracy.finaloutput.combined$dv=="infantmortrate"],na.rm=TRUE)/infantmortrate.democracy.tot.models

infantmortrate.democracy.cdf.empirical.below0

infantmortrate.democracy.final.noweight.estimate
infantmortrate.democracy.final.noweight.se
infantmortrate.democracy.final.noweight.pvalue

infantmortrate.democracy.5sig.onesided

infantmortrate.democracy.tot.models

#deathrate#
deathrate.democracy.tot.models<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$dv=="deathrate"])
deathrate.democracy.max.estimate<-max(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="deathrate"& democracy.finaloutput.combined$keep==1])
deathrate.democracy.min.estimate<-min(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="deathrate"& democracy.finaloutput.combined$keep==1])
deathrate.democracy.5sig.onesided<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$tstat<(-1.64) & democracy.finaloutput.combined$dv=="deathrate"],na.rm=TRUE)/deathrate.democracy.tot.models
deathrate.democracy.final.noweight.estimate<-mean(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="deathrate"& democracy.finaloutput.combined$keep==1])
deathrate.democracy.final.noweight.se<-mean(democracy.finaloutput.combined$se[democracy.finaloutput.combined$dv=="deathrate"& democracy.finaloutput.combined$keep==1])
deathrate.democracy.final.noweight.tstat<-deathrate.democracy.final.noweight.estimate/deathrate.democracy.final.noweight.se
deathrate.democracy.final.noweight.pvalue<-pnorm(deathrate.democracy.final.noweight.tstat)
deathrate.democracy.cdf.empirical.below0<-sum(democracy.finaloutput.combined$keep[(democracy.finaloutput.combined$estimate<0) & democracy.finaloutput.combined$dv=="deathrate"],na.rm=TRUE)/deathrate.democracy.tot.models

deathrate.democracy.cdf.empirical.below0

deathrate.democracy.final.noweight.estimate
deathrate.democracy.final.noweight.se
deathrate.democracy.final.noweight.pvalue

deathrate.democracy.5sig.onesided

deathrate.democracy.tot.models

#pupilsteachers.prim.rat#
pupilsteachers.prim.rat.democracy.tot.models<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$dv=="pupilsteachers.prim.rat"])
pupilsteachers.prim.rat.democracy.max.estimate<-max(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="pupilsteachers.prim.rat"& democracy.finaloutput.combined$keep==1])
pupilsteachers.prim.rat.democracy.min.estimate<-min(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="pupilsteachers.prim.rat"& democracy.finaloutput.combined$keep==1])
pupilsteachers.prim.rat.democracy.5sig.onesided<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$tstat<(-1.64) & democracy.finaloutput.combined$dv=="pupilsteachers.prim.rat"],na.rm=TRUE)/pupilsteachers.prim.rat.democracy.tot.models
pupilsteachers.prim.rat.democracy.final.noweight.estimate<-mean(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="pupilsteachers.prim.rat"& democracy.finaloutput.combined$keep==1])
pupilsteachers.prim.rat.democracy.final.noweight.se<-mean(democracy.finaloutput.combined$se[democracy.finaloutput.combined$dv=="pupilsteachers.prim.rat"& democracy.finaloutput.combined$keep==1])
pupilsteachers.prim.rat.democracy.final.noweight.tstat<-pupilsteachers.prim.rat.democracy.final.noweight.estimate/pupilsteachers.prim.rat.democracy.final.noweight.se
pupilsteachers.prim.rat.democracy.final.noweight.pvalue<-pnorm(pupilsteachers.prim.rat.democracy.final.noweight.tstat)
pupilsteachers.prim.rat.democracy.cdf.empirical.below0<-sum(democracy.finaloutput.combined$keep[(democracy.finaloutput.combined$estimate<0) & democracy.finaloutput.combined$dv=="pupilsteachers.prim.rat"],na.rm=TRUE)/pupilsteachers.prim.rat.democracy.tot.models

pupilsteachers.prim.rat.democracy.tot.adjrsq<-sum(democracy.finaloutput.combined$adjrsq[democracy.finaloutput.combined$keep==1 & democracy.finaloutput.combined$dv=="pupilsteachers.prim.rat"],na.rm=TRUE)
democracy.finaloutput.combined$weights[democracy.finaloutput.combined$keep==1 & democracy.finaloutput.combined$dv=="pupilsteachers.prim.rat"]<-democracy.finaloutput.combined$adjrsq[democracy.finaloutput.combined$keep==1 & democracy.finaloutput.combined$dv=="pupilsteachers.prim.rat"]/pupilsteachers.prim.rat.democracy.tot.adjrsq
pupilsteachers.prim.rat.democracy.final.weight.estimate<-sum((democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="pupilsteachers.prim.rat"& democracy.finaloutput.combined$keep==1]*democracy.finaloutput.combined$weight[democracy.finaloutput.combined$dv=="pupilsteachers.prim.rat"& democracy.finaloutput.combined$keep==1]),na.rm=TRUE)
pupilsteachers.prim.rat.democracy.final.weight.se<-sum((democracy.finaloutput.combined$se[democracy.finaloutput.combined$dv=="pupilsteachers.prim.rat"& democracy.finaloutput.combined$keep==1]*democracy.finaloutput.combined$weight[democracy.finaloutput.combined$dv=="pupilsteachers.prim.rat"& democracy.finaloutput.combined$keep==1]),na.rm=TRUE)
pupilsteachers.prim.rat.democracy.final.weight.tstat<-pupilsteachers.prim.rat.democracy.final.weight.estimate/pupilsteachers.prim.rat.democracy.final.weight.se
pupilsteachers.prim.rat.democracy.final.weight.pvalue<-pnorm(pupilsteachers.prim.rat.democracy.final.weight.tstat)
pupilsteachers.prim.rat.democracy.cdf.sala.below0<-pnorm(0,pupilsteachers.prim.rat.democracy.final.weight.estimate,pupilsteachers.prim.rat.democracy.final.weight.se) 

pupilsteachers.prim.rat.democracy.cdf.empirical.below0

pupilsteachers.prim.rat.democracy.final.noweight.estimate
pupilsteachers.prim.rat.democracy.final.noweight.se
pupilsteachers.prim.rat.democracy.final.noweight.pvalue

pupilsteachers.prim.rat.democracy.5sig.onesided

pupilsteachers.prim.rat.democracy.tot.models

#enrollmentrate.prim#
enrollmentrate.prim.democracy.tot.models<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$dv=="enrollmentrate.prim"])
enrollmentrate.prim.democracy.max.estimate<-max(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="enrollmentrate.prim"& democracy.finaloutput.combined$keep==1])
enrollmentrate.prim.democracy.min.estimate<-min(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="enrollmentrate.prim"& democracy.finaloutput.combined$keep==1])
enrollmentrate.prim.democracy.5sig.onesided<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$tstat>1.64 & democracy.finaloutput.combined$dv=="enrollmentrate.prim"],na.rm=TRUE)/enrollmentrate.prim.democracy.tot.models
enrollmentrate.prim.democracy.final.noweight.estimate<-mean(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="enrollmentrate.prim"& democracy.finaloutput.combined$keep==1])
enrollmentrate.prim.democracy.final.noweight.se<-mean(democracy.finaloutput.combined$se[democracy.finaloutput.combined$dv=="enrollmentrate.prim"& democracy.finaloutput.combined$keep==1])
enrollmentrate.prim.democracy.final.noweight.tstat<-enrollmentrate.prim.democracy.final.noweight.estimate/enrollmentrate.prim.democracy.final.noweight.se
enrollmentrate.prim.democracy.final.noweight.pvalue<-1-pnorm(enrollmentrate.prim.democracy.final.noweight.tstat)
enrollmentrate.prim.democracy.cdf.empirical.above0<-sum(democracy.finaloutput.combined$keep[(democracy.finaloutput.combined$estimate>0) & democracy.finaloutput.combined$dv=="enrollmentrate.prim"],na.rm=TRUE)/enrollmentrate.prim.democracy.tot.models

enrollmentrate.prim.democracy.tot.adjrsq<-sum(democracy.finaloutput.combined$adjrsq[democracy.finaloutput.combined$keep==1 & democracy.finaloutput.combined$dv=="enrollmentrate.prim"],na.rm=TRUE)
democracy.finaloutput.combined$weights[democracy.finaloutput.combined$keep==1 & democracy.finaloutput.combined$dv=="enrollmentrate.prim"]<-democracy.finaloutput.combined$adjrsq[democracy.finaloutput.combined$keep==1 & democracy.finaloutput.combined$dv=="enrollmentrate.prim"]/enrollmentrate.prim.democracy.tot.adjrsq
enrollmentrate.prim.democracy.final.weight.estimate<-sum((democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="enrollmentrate.prim"& democracy.finaloutput.combined$keep==1]*democracy.finaloutput.combined$weight[democracy.finaloutput.combined$dv=="enrollmentrate.prim"& democracy.finaloutput.combined$keep==1]),na.rm=TRUE)
enrollmentrate.prim.democracy.final.weight.se<-sum((democracy.finaloutput.combined$se[democracy.finaloutput.combined$dv=="enrollmentrate.prim"& democracy.finaloutput.combined$keep==1]*democracy.finaloutput.combined$weight[democracy.finaloutput.combined$dv=="enrollmentrate.prim"& democracy.finaloutput.combined$keep==1]),na.rm=TRUE)
enrollmentrate.prim.democracy.final.weight.tstat<-enrollmentrate.prim.democracy.final.weight.estimate/enrollmentrate.prim.democracy.final.weight.se
enrollmentrate.prim.democracy.final.weight.pvalue<-1-pnorm(enrollmentrate.prim.democracy.final.weight.tstat)
enrollmentrate.prim.democracy.cdf.sala.above0<-1-pnorm(0,enrollmentrate.prim.democracy.final.weight.estimate,enrollmentrate.prim.democracy.final.weight.se) 

enrollmentrate.prim.democracy.cdf.empirical.above0

enrollmentrate.prim.democracy.final.noweight.estimate
enrollmentrate.prim.democracy.final.noweight.se
enrollmentrate.prim.democracy.final.noweight.pvalue

enrollmentrate.prim.democracy.5sig.onesided

enrollmentrate.prim.democracy.tot.models

#pupilsteachers.sec.rat#
pupilsteachers.sec.rat.democracy.tot.models<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$dv=="pupilsteachers.sec.rat"])
pupilsteachers.sec.rat.democracy.max.estimate<-max(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="pupilsteachers.sec.rat"& democracy.finaloutput.combined$keep==1])
pupilsteachers.sec.rat.democracy.min.estimate<-min(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="pupilsteachers.sec.rat"& democracy.finaloutput.combined$keep==1])
pupilsteachers.sec.rat.democracy.5sig.onesided<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$tstat<(-1.64) & democracy.finaloutput.combined$dv=="pupilsteachers.sec.rat"],na.rm=TRUE)/pupilsteachers.sec.rat.democracy.tot.models
pupilsteachers.sec.rat.democracy.final.noweight.estimate<-mean(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="pupilsteachers.sec.rat"& democracy.finaloutput.combined$keep==1])
pupilsteachers.sec.rat.democracy.final.noweight.se<-mean(democracy.finaloutput.combined$se[democracy.finaloutput.combined$dv=="pupilsteachers.sec.rat"& democracy.finaloutput.combined$keep==1])
pupilsteachers.sec.rat.democracy.final.noweight.tstat<-pupilsteachers.sec.rat.democracy.final.noweight.estimate/pupilsteachers.sec.rat.democracy.final.noweight.se
pupilsteachers.sec.rat.democracy.final.noweight.pvalue<-pnorm(pupilsteachers.sec.rat.democracy.final.noweight.tstat)
pupilsteachers.sec.rat.democracy.cdf.empirical.below0<-sum(democracy.finaloutput.combined$keep[(democracy.finaloutput.combined$estimate<0) & democracy.finaloutput.combined$dv=="pupilsteachers.sec.rat"],na.rm=TRUE)/pupilsteachers.sec.rat.democracy.tot.models

pupilsteachers.sec.rat.democracy.tot.adjrsq<-sum(democracy.finaloutput.combined$adjrsq[democracy.finaloutput.combined$keep==1 & democracy.finaloutput.combined$dv=="pupilsteachers.sec.rat"],na.rm=TRUE)
democracy.finaloutput.combined$weights[democracy.finaloutput.combined$keep==1 & democracy.finaloutput.combined$dv=="pupilsteachers.sec.rat"]<-democracy.finaloutput.combined$adjrsq[democracy.finaloutput.combined$keep==1 & democracy.finaloutput.combined$dv=="pupilsteachers.sec.rat"]/pupilsteachers.sec.rat.democracy.tot.adjrsq
pupilsteachers.sec.rat.democracy.final.weight.estimate<-sum((democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="pupilsteachers.sec.rat"& democracy.finaloutput.combined$keep==1]*democracy.finaloutput.combined$weight[democracy.finaloutput.combined$dv=="pupilsteachers.sec.rat"& democracy.finaloutput.combined$keep==1]),na.rm=TRUE)
pupilsteachers.sec.rat.democracy.final.weight.se<-sum((democracy.finaloutput.combined$se[democracy.finaloutput.combined$dv=="pupilsteachers.sec.rat"& democracy.finaloutput.combined$keep==1]*democracy.finaloutput.combined$weight[democracy.finaloutput.combined$dv=="pupilsteachers.sec.rat"& democracy.finaloutput.combined$keep==1]),na.rm=TRUE)
pupilsteachers.sec.rat.democracy.final.weight.tstat<-pupilsteachers.sec.rat.democracy.final.weight.estimate/pupilsteachers.sec.rat.democracy.final.weight.se
pupilsteachers.sec.rat.democracy.final.weight.pvalue<-pnorm(pupilsteachers.sec.rat.democracy.final.weight.tstat)
pupilsteachers.sec.rat.democracy.cdf.sala.below0<-pnorm(0,pupilsteachers.sec.rat.democracy.final.weight.estimate,pupilsteachers.sec.rat.democracy.final.weight.se) 

pupilsteachers.sec.rat.democracy.cdf.empirical.below0

pupilsteachers.sec.rat.democracy.final.noweight.estimate
pupilsteachers.sec.rat.democracy.final.noweight.se
pupilsteachers.sec.rat.democracy.final.noweight.pvalue

pupilsteachers.sec.rat.democracy.5sig.onesided

pupilsteachers.sec.rat.democracy.tot.models

#enrollmentrate.sec#
enrollmentrate.sec.democracy.tot.models<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$dv=="enrollmentrate.sec"])
enrollmentrate.sec.democracy.max.estimate<-max(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="enrollmentrate.sec"& democracy.finaloutput.combined$keep==1])
enrollmentrate.sec.democracy.min.estimate<-min(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="enrollmentrate.sec"& democracy.finaloutput.combined$keep==1])
enrollmentrate.sec.democracy.5sig.onesided<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$tstat>1.64 & democracy.finaloutput.combined$dv=="enrollmentrate.sec"],na.rm=TRUE)/enrollmentrate.sec.democracy.tot.models
enrollmentrate.sec.democracy.final.noweight.estimate<-mean(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="enrollmentrate.sec"& democracy.finaloutput.combined$keep==1])
enrollmentrate.sec.democracy.final.noweight.se<-mean(democracy.finaloutput.combined$se[democracy.finaloutput.combined$dv=="enrollmentrate.sec"& democracy.finaloutput.combined$keep==1])
enrollmentrate.sec.democracy.final.noweight.tstat<-enrollmentrate.sec.democracy.final.noweight.estimate/enrollmentrate.sec.democracy.final.noweight.se
enrollmentrate.sec.democracy.final.noweight.pvalue<-1-pnorm(enrollmentrate.sec.democracy.final.noweight.tstat)
enrollmentrate.sec.democracy.cdf.empirical.above0<-sum(democracy.finaloutput.combined$keep[(democracy.finaloutput.combined$estimate>0) & democracy.finaloutput.combined$dv=="enrollmentrate.sec"],na.rm=TRUE)/enrollmentrate.sec.democracy.tot.models

enrollmentrate.sec.democracy.cdf.empirical.above0

enrollmentrate.sec.democracy.final.noweight.estimate
enrollmentrate.sec.democracy.final.noweight.se
enrollmentrate.sec.democracy.final.noweight.pvalue

enrollmentrate.sec.democracy.5sig.onesided

enrollmentrate.sec.democracy.tot.models


#sanitation.tot#
sanitation.tot.democracy.tot.models<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$dv=="sanitation.tot"])
sanitation.tot.democracy.max.estimate<-max(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="sanitation.tot"& democracy.finaloutput.combined$keep==1])
sanitation.tot.democracy.min.estimate<-min(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="sanitation.tot"& democracy.finaloutput.combined$keep==1])
sanitation.tot.democracy.5sig.onesided<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$tstat>1.64 & democracy.finaloutput.combined$dv=="sanitation.tot"],na.rm=TRUE)/sanitation.tot.democracy.tot.models
sanitation.tot.democracy.final.noweight.estimate<-mean(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="sanitation.tot"& democracy.finaloutput.combined$keep==1])
sanitation.tot.democracy.final.noweight.se<-mean(democracy.finaloutput.combined$se[democracy.finaloutput.combined$dv=="sanitation.tot"& democracy.finaloutput.combined$keep==1])
sanitation.tot.democracy.final.noweight.tstat<-sanitation.tot.democracy.final.noweight.estimate/sanitation.tot.democracy.final.noweight.se
sanitation.tot.democracy.final.noweight.pvalue<-1-pnorm(sanitation.tot.democracy.final.noweight.tstat)
sanitation.tot.democracy.cdf.empirical.above0<-sum(democracy.finaloutput.combined$keep[(democracy.finaloutput.combined$estimate>0) & democracy.finaloutput.combined$dv=="sanitation.tot"],na.rm=TRUE)/sanitation.tot.democracy.tot.models

sanitation.tot.democracy.cdf.empirical.above0

sanitation.tot.democracy.final.noweight.estimate
sanitation.tot.democracy.final.noweight.se
sanitation.tot.democracy.final.noweight.pvalue

sanitation.tot.democracy.5sig.onesided

sanitation.tot.democracy.tot.models

#primcomp.rate#
primcomp.rate.democracy.tot.models<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$dv=="primcomp.rate"])
primcomp.rate.democracy.max.estimate<-max(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="primcomp.rate"& democracy.finaloutput.combined$keep==1])
primcomp.rate.democracy.min.estimate<-min(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="primcomp.rate"& democracy.finaloutput.combined$keep==1])
primcomp.rate.democracy.5sig.onesided<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$tstat>1.64 & democracy.finaloutput.combined$dv=="primcomp.rate"],na.rm=TRUE)/primcomp.rate.democracy.tot.models
primcomp.rate.democracy.final.noweight.estimate<-mean(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="primcomp.rate"& democracy.finaloutput.combined$keep==1])
primcomp.rate.democracy.final.noweight.se<-mean(democracy.finaloutput.combined$se[democracy.finaloutput.combined$dv=="primcomp.rate"& democracy.finaloutput.combined$keep==1])
primcomp.rate.democracy.final.noweight.tstat<-primcomp.rate.democracy.final.noweight.estimate/primcomp.rate.democracy.final.noweight.se
primcomp.rate.democracy.final.noweight.pvalue<-1-pnorm(primcomp.rate.democracy.final.noweight.tstat)
primcomp.rate.democracy.cdf.empirical.above0<-sum(democracy.finaloutput.combined$keep[(democracy.finaloutput.combined$estimate>0) & democracy.finaloutput.combined$dv=="primcomp.rate"],na.rm=TRUE)/primcomp.rate.democracy.tot.models

primcomp.rate.democracy.cdf.empirical.above0
primcomp.rate.democracy.cdf.sala.above0

primcomp.rate.democracy.final.noweight.estimate
primcomp.rate.democracy.final.noweight.se
primcomp.rate.democracy.final.noweight.pvalue

primcomp.rate.democracy.5sig.onesided

primcomp.rate.democracy.tot.models

#physicians#
physicians.democracy.tot.models<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$dv=="physicians"])
physicians.democracy.max.estimate<-max(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="physicians"& democracy.finaloutput.combined$keep==1])
physicians.democracy.min.estimate<-min(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="physicians"& democracy.finaloutput.combined$keep==1])
physicians.democracy.5sig.onesided<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$tstat>1.64 & democracy.finaloutput.combined$dv=="physicians"],na.rm=TRUE)/physicians.democracy.tot.models
physicians.democracy.final.noweight.estimate<-mean(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="physicians"& democracy.finaloutput.combined$keep==1])
physicians.democracy.final.noweight.se<-mean(democracy.finaloutput.combined$se[democracy.finaloutput.combined$dv=="physicians"& democracy.finaloutput.combined$keep==1])
physicians.democracy.final.noweight.tstat<-physicians.democracy.final.noweight.estimate/physicians.democracy.final.noweight.se
physicians.democracy.final.noweight.pvalue<-1-pnorm(physicians.democracy.final.noweight.tstat)
physicians.democracy.cdf.empirical.above0<-sum(democracy.finaloutput.combined$keep[(democracy.finaloutput.combined$estimate>0) & democracy.finaloutput.combined$dv=="physicians"],na.rm=TRUE)/physicians.democracy.tot.models

physicians.democracy.cdf.empirical.above0
physicians.democracy.cdf.sala.above0

physicians.democracy.final.noweight.estimate
physicians.democracy.final.noweight.se
physicians.democracy.final.noweight.pvalue

physicians.democracy.5sig.onesided

physicians.democracy.tot.models

#lifeexpect#
lifeexpect.democracy.tot.models<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$dv=="lifeexpect"])
lifeexpect.democracy.max.estimate<-max(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="lifeexpect"& democracy.finaloutput.combined$keep==1])
lifeexpect.democracy.min.estimate<-min(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="lifeexpect"& democracy.finaloutput.combined$keep==1])
lifeexpect.democracy.5sig.onesided<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$tstat>1.64 & democracy.finaloutput.combined$dv=="lifeexpect"],na.rm=TRUE)/lifeexpect.democracy.tot.models
lifeexpect.democracy.final.noweight.estimate<-mean(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="lifeexpect"& democracy.finaloutput.combined$keep==1])
lifeexpect.democracy.final.noweight.se<-mean(democracy.finaloutput.combined$se[democracy.finaloutput.combined$dv=="lifeexpect"& democracy.finaloutput.combined$keep==1])
lifeexpect.democracy.final.noweight.tstat<-lifeexpect.democracy.final.noweight.estimate/lifeexpect.democracy.final.noweight.se
lifeexpect.democracy.final.noweight.pvalue<-1-pnorm(lifeexpect.democracy.final.noweight.tstat)
lifeexpect.democracy.cdf.empirical.above0<-sum(democracy.finaloutput.combined$keep[(democracy.finaloutput.combined$estimate>0) & democracy.finaloutput.combined$dv=="lifeexpect"],na.rm=TRUE)/lifeexpect.democracy.tot.models

lifeexpect.democracy.cdf.empirical.above0

lifeexpect.democracy.final.noweight.estimate
lifeexpect.democracy.final.noweight.se
lifeexpect.democracy.final.noweight.pvalue

lifeexpect.democracy.5sig.onesided

lifeexpect.democracy.tot.models

#beds#
beds.democracy.tot.models<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$dv=="beds"])
beds.democracy.max.estimate<-max(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="beds"& democracy.finaloutput.combined$keep==1])
beds.democracy.min.estimate<-min(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="beds"& democracy.finaloutput.combined$keep==1])
beds.democracy.5sig.onesided<-sum(democracy.finaloutput.combined$keep[democracy.finaloutput.combined$tstat>1.64 & democracy.finaloutput.combined$dv=="beds"],na.rm=TRUE)/beds.democracy.tot.models
beds.democracy.final.noweight.estimate<-mean(democracy.finaloutput.combined$estimate[democracy.finaloutput.combined$dv=="beds"& democracy.finaloutput.combined$keep==1])
beds.democracy.final.noweight.se<-mean(democracy.finaloutput.combined$se[democracy.finaloutput.combined$dv=="beds"& democracy.finaloutput.combined$keep==1])
beds.democracy.final.noweight.tstat<-beds.democracy.final.noweight.estimate/beds.democracy.final.noweight.se
beds.democracy.final.noweight.pvalue<-1-pnorm(beds.democracy.final.noweight.tstat)
beds.democracy.cdf.empirical.above0<-sum(democracy.finaloutput.combined$keep[(democracy.finaloutput.combined$estimate>0) & democracy.finaloutput.combined$dv=="beds"],na.rm=TRUE)/beds.democracy.tot.models

beds.democracy.cdf.empirical.above0

beds.democracy.final.noweight.estimate
beds.democracy.final.noweight.se
beds.democracy.final.noweight.pvalue

beds.democracy.5sig.onesided

beds.democracy.tot.models

#immunizdpt#
immunizdpt.polity2.tot.models<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$dv=="immunizdpt"])
immunizdpt.polity2.max.estimate<-max(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="immunizdpt"& polity2.finaloutput.combined$keep==1])
immunizdpt.polity2.min.estimate<-min(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="immunizdpt"& polity2.finaloutput.combined$keep==1])
immunizdpt.polity2.5sig.onesided<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$tstat>1.64 & polity2.finaloutput.combined$dv=="immunizdpt"],na.rm=TRUE)/immunizdpt.polity2.tot.models
immunizdpt.polity2.final.noweight.estimate<-mean(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="immunizdpt"& polity2.finaloutput.combined$keep==1])
immunizdpt.polity2.final.noweight.se<-mean(polity2.finaloutput.combined$se[polity2.finaloutput.combined$dv=="immunizdpt"& polity2.finaloutput.combined$keep==1])
immunizdpt.polity2.final.noweight.tstat<-immunizdpt.polity2.final.noweight.estimate/immunizdpt.polity2.final.noweight.se
immunizdpt.polity2.final.noweight.pvalue<-1-pnorm(immunizdpt.polity2.final.noweight.tstat)
immunizdpt.polity2.cdf.empirical.above0<-sum(polity2.finaloutput.combined$keep[(polity2.finaloutput.combined$estimate>0) & polity2.finaloutput.combined$dv=="immunizdpt"],na.rm=TRUE)/immunizdpt.polity2.tot.models

immunizdpt.polity2.cdf.empirical.above0

immunizdpt.polity2.final.noweight.estimate
immunizdpt.polity2.final.noweight.se
immunizdpt.polity2.final.noweight.pvalue

immunizdpt.polity2.5sig.onesided

immunizdpt.polity2.tot.models

#measles#
measles.polity2.tot.models<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$dv=="measles"])
measles.polity2.max.estimate<-max(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="measles"& polity2.finaloutput.combined$keep==1])
measles.polity2.min.estimate<-min(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="measles"& polity2.finaloutput.combined$keep==1])
measles.polity2.5sig.onesided<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$tstat>1.64 & polity2.finaloutput.combined$dv=="measles"],na.rm=TRUE)/measles.polity2.tot.models
measles.polity2.final.noweight.estimate<-mean(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="measles"& polity2.finaloutput.combined$keep==1])
measles.polity2.final.noweight.se<-mean(polity2.finaloutput.combined$se[polity2.finaloutput.combined$dv=="measles"& polity2.finaloutput.combined$keep==1])
measles.polity2.final.noweight.tstat<-measles.polity2.final.noweight.estimate/measles.polity2.final.noweight.se
measles.polity2.final.noweight.pvalue<-1-pnorm(measles.polity2.final.noweight.tstat)
measles.polity2.cdf.empirical.above0<-sum(polity2.finaloutput.combined$keep[(polity2.finaloutput.combined$estimate>0) & polity2.finaloutput.combined$dv=="measles"],na.rm=TRUE)/measles.polity2.tot.models

measles.polity2.cdf.empirical.above0

measles.polity2.final.noweight.estimate
measles.polity2.final.noweight.se
measles.polity2.final.noweight.pvalue

measles.polity2.5sig.onesided

measles.polity2.tot.models

#water.tot#
water.tot.polity2.tot.models<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$dv=="water.tot"])
water.tot.polity2.max.estimate<-max(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="water.tot"& polity2.finaloutput.combined$keep==1])
water.tot.polity2.min.estimate<-min(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="water.tot"& polity2.finaloutput.combined$keep==1])
water.tot.polity2.5sig.onesided<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$tstat<1.64 & polity2.finaloutput.combined$dv=="water.tot"],na.rm=TRUE)/water.tot.polity2.tot.models
water.tot.polity2.final.noweight.estimate<-mean(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="water.tot"& polity2.finaloutput.combined$keep==1])
water.tot.polity2.final.noweight.se<-mean(polity2.finaloutput.combined$se[polity2.finaloutput.combined$dv=="water.tot"& polity2.finaloutput.combined$keep==1])
water.tot.polity2.final.noweight.tstat<-water.tot.polity2.final.noweight.estimate/water.tot.polity2.final.noweight.se
water.tot.polity2.final.noweight.pvalue<-1-pnorm(water.tot.polity2.final.noweight.tstat)
water.tot.polity2.cdf.empirical.above0<-sum(polity2.finaloutput.combined$keep[(polity2.finaloutput.combined$estimate>0) & polity2.finaloutput.combined$dv=="water.tot"],na.rm=TRUE)/water.tot.polity2.tot.models

water.tot.polity2.cdf.empirical.above0

water.tot.polity2.final.noweight.estimate
water.tot.polity2.final.noweight.se
water.tot.polity2.final.noweight.pvalue

water.tot.polity2.5sig.onesided

water.tot.polity2.tot.models

#infantmortrate#
infantmortrate.polity2.tot.models<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$dv=="infantmortrate"])
infantmortrate.polity2.max.estimate<-max(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="infantmortrate"& polity2.finaloutput.combined$keep==1])
infantmortrate.polity2.min.estimate<-min(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="infantmortrate"& polity2.finaloutput.combined$keep==1])
infantmortrate.polity2.5sig.onesided<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$tstat<(-1.64) & polity2.finaloutput.combined$dv=="infantmortrate"],na.rm=TRUE)/infantmortrate.polity2.tot.models
infantmortrate.polity2.final.noweight.estimate<-mean(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="infantmortrate"& polity2.finaloutput.combined$keep==1])
infantmortrate.polity2.final.noweight.se<-mean(polity2.finaloutput.combined$se[polity2.finaloutput.combined$dv=="infantmortrate"& polity2.finaloutput.combined$keep==1])
infantmortrate.polity2.final.noweight.tstat<-infantmortrate.polity2.final.noweight.estimate/infantmortrate.polity2.final.noweight.se
infantmortrate.polity2.final.noweight.pvalue<-pnorm(infantmortrate.polity2.final.noweight.tstat)
infantmortrate.polity2.cdf.empirical.below0<-sum(polity2.finaloutput.combined$keep[(polity2.finaloutput.combined$estimate<0) & polity2.finaloutput.combined$dv=="infantmortrate"],na.rm=TRUE)/infantmortrate.polity2.tot.models

infantmortrate.polity2.cdf.empirical.below0

infantmortrate.polity2.final.noweight.estimate
infantmortrate.polity2.final.noweight.se
infantmortrate.polity2.final.noweight.pvalue

infantmortrate.polity2.5sig.onesided

infantmortrate.polity2.tot.models

#deathrate#
deathrate.polity2.tot.models<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$dv=="deathrate"])
deathrate.polity2.max.estimate<-max(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="deathrate"& polity2.finaloutput.combined$keep==1])
deathrate.polity2.min.estimate<-min(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="deathrate"& polity2.finaloutput.combined$keep==1])
deathrate.polity2.5sig.onesided<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$tstat<(-1.64) & polity2.finaloutput.combined$dv=="deathrate"],na.rm=TRUE)/deathrate.polity2.tot.models
deathrate.polity2.final.noweight.estimate<-mean(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="deathrate"& polity2.finaloutput.combined$keep==1])
deathrate.polity2.final.noweight.se<-mean(polity2.finaloutput.combined$se[polity2.finaloutput.combined$dv=="deathrate"& polity2.finaloutput.combined$keep==1])
deathrate.polity2.final.noweight.tstat<-deathrate.polity2.final.noweight.estimate/deathrate.polity2.final.noweight.se
deathrate.polity2.final.noweight.pvalue<-pnorm(deathrate.polity2.final.noweight.tstat)
deathrate.polity2.cdf.empirical.below0<-sum(polity2.finaloutput.combined$keep[(polity2.finaloutput.combined$estimate<0) & polity2.finaloutput.combined$dv=="deathrate"],na.rm=TRUE)/deathrate.polity2.tot.models

deathrate.polity2.cdf.empirical.below0

deathrate.polity2.final.noweight.estimate
deathrate.polity2.final.noweight.se
deathrate.polity2.final.noweight.pvalue

deathrate.polity2.5sig.onesided

deathrate.polity2.tot.models

#pupilsteachers.prim.rat#
pupilsteachers.prim.rat.polity2.tot.models<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$dv=="pupilsteachers.prim.rat"])
pupilsteachers.prim.rat.polity2.max.estimate<-max(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="pupilsteachers.prim.rat"& polity2.finaloutput.combined$keep==1])
pupilsteachers.prim.rat.polity2.min.estimate<-min(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="pupilsteachers.prim.rat"& polity2.finaloutput.combined$keep==1])
pupilsteachers.prim.rat.polity2.5sig.onesided<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$tstat<(-1.64) & polity2.finaloutput.combined$dv=="pupilsteachers.prim.rat"],na.rm=TRUE)/pupilsteachers.prim.rat.polity2.tot.models
pupilsteachers.prim.rat.polity2.final.noweight.estimate<-mean(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="pupilsteachers.prim.rat"& polity2.finaloutput.combined$keep==1])
pupilsteachers.prim.rat.polity2.final.noweight.se<-mean(polity2.finaloutput.combined$se[polity2.finaloutput.combined$dv=="pupilsteachers.prim.rat"& polity2.finaloutput.combined$keep==1])
pupilsteachers.prim.rat.polity2.final.noweight.tstat<-pupilsteachers.prim.rat.polity2.final.noweight.estimate/pupilsteachers.prim.rat.polity2.final.noweight.se
pupilsteachers.prim.rat.polity2.final.noweight.pvalue<-pnorm(pupilsteachers.prim.rat.polity2.final.noweight.tstat)
pupilsteachers.prim.rat.polity2.cdf.empirical.below0<-sum(polity2.finaloutput.combined$keep[(polity2.finaloutput.combined$estimate<0) & polity2.finaloutput.combined$dv=="pupilsteachers.prim.rat"],na.rm=TRUE)/pupilsteachers.prim.rat.polity2.tot.models

pupilsteachers.prim.rat.polity2.tot.adjrsq<-sum(polity2.finaloutput.combined$adjrsq[polity2.finaloutput.combined$keep==1 & polity2.finaloutput.combined$dv=="pupilsteachers.prim.rat"],na.rm=TRUE)
polity2.finaloutput.combined$weights[polity2.finaloutput.combined$keep==1 & polity2.finaloutput.combined$dv=="pupilsteachers.prim.rat"]<-polity2.finaloutput.combined$adjrsq[polity2.finaloutput.combined$keep==1 & polity2.finaloutput.combined$dv=="pupilsteachers.prim.rat"]/pupilsteachers.prim.rat.polity2.tot.adjrsq
pupilsteachers.prim.rat.polity2.final.weight.estimate<-sum((polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="pupilsteachers.prim.rat"& polity2.finaloutput.combined$keep==1]*polity2.finaloutput.combined$weight[polity2.finaloutput.combined$dv=="pupilsteachers.prim.rat"& polity2.finaloutput.combined$keep==1]),na.rm=TRUE)
pupilsteachers.prim.rat.polity2.final.weight.se<-sum((polity2.finaloutput.combined$se[polity2.finaloutput.combined$dv=="pupilsteachers.prim.rat"& polity2.finaloutput.combined$keep==1]*polity2.finaloutput.combined$weight[polity2.finaloutput.combined$dv=="pupilsteachers.prim.rat"& polity2.finaloutput.combined$keep==1]),na.rm=TRUE)
pupilsteachers.prim.rat.polity2.final.weight.tstat<-pupilsteachers.prim.rat.polity2.final.weight.estimate/pupilsteachers.prim.rat.polity2.final.weight.se
pupilsteachers.prim.rat.polity2.final.weight.pvalue<-pnorm(pupilsteachers.prim.rat.polity2.final.weight.tstat)
pupilsteachers.prim.rat.polity2.cdf.sala.below0<-pnorm(0,pupilsteachers.prim.rat.polity2.final.weight.estimate,pupilsteachers.prim.rat.polity2.final.weight.se) 

pupilsteachers.prim.rat.polity2.cdf.empirical.below0

pupilsteachers.prim.rat.polity2.final.noweight.estimate
pupilsteachers.prim.rat.polity2.final.noweight.se
pupilsteachers.prim.rat.polity2.final.noweight.pvalue

pupilsteachers.prim.rat.polity2.5sig.onesided

pupilsteachers.prim.rat.polity2.tot.models

#enrollmentrate.prim#
enrollmentrate.prim.polity2.tot.models<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$dv=="enrollmentrate.prim"])
enrollmentrate.prim.polity2.max.estimate<-max(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="enrollmentrate.prim"& polity2.finaloutput.combined$keep==1])
enrollmentrate.prim.polity2.min.estimate<-min(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="enrollmentrate.prim"& polity2.finaloutput.combined$keep==1])
enrollmentrate.prim.polity2.5sig.onesided<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$tstat>1.64 & polity2.finaloutput.combined$dv=="enrollmentrate.prim"],na.rm=TRUE)/enrollmentrate.prim.polity2.tot.models
enrollmentrate.prim.polity2.final.noweight.estimate<-mean(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="enrollmentrate.prim"& polity2.finaloutput.combined$keep==1])
enrollmentrate.prim.polity2.final.noweight.se<-mean(polity2.finaloutput.combined$se[polity2.finaloutput.combined$dv=="enrollmentrate.prim"& polity2.finaloutput.combined$keep==1])
enrollmentrate.prim.polity2.final.noweight.tstat<-enrollmentrate.prim.polity2.final.noweight.estimate/enrollmentrate.prim.polity2.final.noweight.se
enrollmentrate.prim.polity2.final.noweight.pvalue<-1-pnorm(enrollmentrate.prim.polity2.final.noweight.tstat)
enrollmentrate.prim.polity2.cdf.empirical.above0<-sum(polity2.finaloutput.combined$keep[(polity2.finaloutput.combined$estimate>0) & polity2.finaloutput.combined$dv=="enrollmentrate.prim"],na.rm=TRUE)/enrollmentrate.prim.polity2.tot.models

enrollmentrate.prim.polity2.tot.adjrsq<-sum(polity2.finaloutput.combined$adjrsq[polity2.finaloutput.combined$keep==1 & polity2.finaloutput.combined$dv=="enrollmentrate.prim"],na.rm=TRUE)
polity2.finaloutput.combined$weights[polity2.finaloutput.combined$keep==1 & polity2.finaloutput.combined$dv=="enrollmentrate.prim"]<-polity2.finaloutput.combined$adjrsq[polity2.finaloutput.combined$keep==1 & polity2.finaloutput.combined$dv=="enrollmentrate.prim"]/enrollmentrate.prim.polity2.tot.adjrsq
enrollmentrate.prim.polity2.final.weight.estimate<-sum((polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="enrollmentrate.prim"& polity2.finaloutput.combined$keep==1]*polity2.finaloutput.combined$weight[polity2.finaloutput.combined$dv=="enrollmentrate.prim"& polity2.finaloutput.combined$keep==1]),na.rm=TRUE)
enrollmentrate.prim.polity2.final.weight.se<-sum((polity2.finaloutput.combined$se[polity2.finaloutput.combined$dv=="enrollmentrate.prim"& polity2.finaloutput.combined$keep==1]*polity2.finaloutput.combined$weight[polity2.finaloutput.combined$dv=="enrollmentrate.prim"& polity2.finaloutput.combined$keep==1]),na.rm=TRUE)
enrollmentrate.prim.polity2.final.weight.tstat<-enrollmentrate.prim.polity2.final.weight.estimate/enrollmentrate.prim.polity2.final.weight.se
enrollmentrate.prim.polity2.final.weight.pvalue<-1-pnorm(enrollmentrate.prim.polity2.final.weight.tstat)
enrollmentrate.prim.polity2.cdf.sala.above0<-1-pnorm(0,enrollmentrate.prim.polity2.final.weight.estimate,enrollmentrate.prim.polity2.final.weight.se) 

enrollmentrate.prim.polity2.cdf.empirical.above0

enrollmentrate.prim.polity2.final.noweight.estimate
enrollmentrate.prim.polity2.final.noweight.se
enrollmentrate.prim.polity2.final.noweight.pvalue

enrollmentrate.prim.polity2.5sig.onesided

enrollmentrate.prim.polity2.tot.models

#pupilsteachers.sec.rat#
pupilsteachers.sec.rat.polity2.tot.models<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$dv=="pupilsteachers.sec.rat"])
pupilsteachers.sec.rat.polity2.max.estimate<-max(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="pupilsteachers.sec.rat"& polity2.finaloutput.combined$keep==1])
pupilsteachers.sec.rat.polity2.min.estimate<-min(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="pupilsteachers.sec.rat"& polity2.finaloutput.combined$keep==1])
pupilsteachers.sec.rat.polity2.5sig.onesided<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$tstat<(-1.64) & polity2.finaloutput.combined$dv=="pupilsteachers.sec.rat"],na.rm=TRUE)/pupilsteachers.sec.rat.polity2.tot.models
pupilsteachers.sec.rat.polity2.final.noweight.estimate<-mean(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="pupilsteachers.sec.rat"& polity2.finaloutput.combined$keep==1])
pupilsteachers.sec.rat.polity2.final.noweight.se<-mean(polity2.finaloutput.combined$se[polity2.finaloutput.combined$dv=="pupilsteachers.sec.rat"& polity2.finaloutput.combined$keep==1])
pupilsteachers.sec.rat.polity2.final.noweight.tstat<-pupilsteachers.sec.rat.polity2.final.noweight.estimate/pupilsteachers.sec.rat.polity2.final.noweight.se
pupilsteachers.sec.rat.polity2.final.noweight.pvalue<-pnorm(pupilsteachers.sec.rat.polity2.final.noweight.tstat)
pupilsteachers.sec.rat.polity2.cdf.empirical.below0<-sum(polity2.finaloutput.combined$keep[(polity2.finaloutput.combined$estimate<0) & polity2.finaloutput.combined$dv=="pupilsteachers.sec.rat"],na.rm=TRUE)/pupilsteachers.sec.rat.polity2.tot.models

pupilsteachers.sec.rat.polity2.tot.adjrsq<-sum(polity2.finaloutput.combined$adjrsq[polity2.finaloutput.combined$keep==1 & polity2.finaloutput.combined$dv=="pupilsteachers.sec.rat"],na.rm=TRUE)
polity2.finaloutput.combined$weights[polity2.finaloutput.combined$keep==1 & polity2.finaloutput.combined$dv=="pupilsteachers.sec.rat"]<-polity2.finaloutput.combined$adjrsq[polity2.finaloutput.combined$keep==1 & polity2.finaloutput.combined$dv=="pupilsteachers.sec.rat"]/pupilsteachers.sec.rat.polity2.tot.adjrsq
pupilsteachers.sec.rat.polity2.final.weight.estimate<-sum((polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="pupilsteachers.sec.rat"& polity2.finaloutput.combined$keep==1]*polity2.finaloutput.combined$weight[polity2.finaloutput.combined$dv=="pupilsteachers.sec.rat"& polity2.finaloutput.combined$keep==1]),na.rm=TRUE)
pupilsteachers.sec.rat.polity2.final.weight.se<-sum((polity2.finaloutput.combined$se[polity2.finaloutput.combined$dv=="pupilsteachers.sec.rat"& polity2.finaloutput.combined$keep==1]*polity2.finaloutput.combined$weight[polity2.finaloutput.combined$dv=="pupilsteachers.sec.rat"& polity2.finaloutput.combined$keep==1]),na.rm=TRUE)
pupilsteachers.sec.rat.polity2.final.weight.tstat<-pupilsteachers.sec.rat.polity2.final.weight.estimate/pupilsteachers.sec.rat.polity2.final.weight.se
pupilsteachers.sec.rat.polity2.final.weight.pvalue<-pnorm(pupilsteachers.sec.rat.polity2.final.weight.tstat)
pupilsteachers.sec.rat.polity2.cdf.sala.below0<-pnorm(0,pupilsteachers.sec.rat.polity2.final.weight.estimate,pupilsteachers.sec.rat.polity2.final.weight.se) 

pupilsteachers.sec.rat.polity2.cdf.empirical.below0

pupilsteachers.sec.rat.polity2.final.noweight.estimate
pupilsteachers.sec.rat.polity2.final.noweight.se
pupilsteachers.sec.rat.polity2.final.noweight.pvalue

pupilsteachers.sec.rat.polity2.5sig.onesided

pupilsteachers.sec.rat.polity2.tot.models

#enrollmentrate.sec#
enrollmentrate.sec.polity2.tot.models<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$dv=="enrollmentrate.sec"])
enrollmentrate.sec.polity2.max.estimate<-max(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="enrollmentrate.sec"& polity2.finaloutput.combined$keep==1])
enrollmentrate.sec.polity2.min.estimate<-min(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="enrollmentrate.sec"& polity2.finaloutput.combined$keep==1])
enrollmentrate.sec.polity2.5sig.onesided<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$tstat>1.64 & polity2.finaloutput.combined$dv=="enrollmentrate.sec"],na.rm=TRUE)/enrollmentrate.sec.polity2.tot.models
enrollmentrate.sec.polity2.final.noweight.estimate<-mean(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="enrollmentrate.sec"& polity2.finaloutput.combined$keep==1])
enrollmentrate.sec.polity2.final.noweight.se<-mean(polity2.finaloutput.combined$se[polity2.finaloutput.combined$dv=="enrollmentrate.sec"& polity2.finaloutput.combined$keep==1])
enrollmentrate.sec.polity2.final.noweight.tstat<-enrollmentrate.sec.polity2.final.noweight.estimate/enrollmentrate.sec.polity2.final.noweight.se
enrollmentrate.sec.polity2.final.noweight.pvalue<-1-pnorm(enrollmentrate.sec.polity2.final.noweight.tstat)
enrollmentrate.sec.polity2.cdf.empirical.above0<-sum(polity2.finaloutput.combined$keep[(polity2.finaloutput.combined$estimate>0) & polity2.finaloutput.combined$dv=="enrollmentrate.sec"],na.rm=TRUE)/enrollmentrate.sec.polity2.tot.models

enrollmentrate.sec.polity2.cdf.empirical.above0

enrollmentrate.sec.polity2.final.noweight.estimate
enrollmentrate.sec.polity2.final.noweight.se
enrollmentrate.sec.polity2.final.noweight.pvalue

enrollmentrate.sec.polity2.5sig.onesided

enrollmentrate.sec.polity2.tot.models


#sanitation.tot#
sanitation.tot.polity2.tot.models<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$dv=="sanitation.tot"])
sanitation.tot.polity2.max.estimate<-max(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="sanitation.tot"& polity2.finaloutput.combined$keep==1])
sanitation.tot.polity2.min.estimate<-min(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="sanitation.tot"& polity2.finaloutput.combined$keep==1])
sanitation.tot.polity2.5sig.onesided<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$tstat>1.64 & polity2.finaloutput.combined$dv=="sanitation.tot"],na.rm=TRUE)/sanitation.tot.polity2.tot.models
sanitation.tot.polity2.final.noweight.estimate<-mean(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="sanitation.tot"& polity2.finaloutput.combined$keep==1])
sanitation.tot.polity2.final.noweight.se<-mean(polity2.finaloutput.combined$se[polity2.finaloutput.combined$dv=="sanitation.tot"& polity2.finaloutput.combined$keep==1])
sanitation.tot.polity2.final.noweight.tstat<-sanitation.tot.polity2.final.noweight.estimate/sanitation.tot.polity2.final.noweight.se
sanitation.tot.polity2.final.noweight.pvalue<-1-pnorm(sanitation.tot.polity2.final.noweight.tstat)
sanitation.tot.polity2.cdf.empirical.above0<-sum(polity2.finaloutput.combined$keep[(polity2.finaloutput.combined$estimate>0) & polity2.finaloutput.combined$dv=="sanitation.tot"],na.rm=TRUE)/sanitation.tot.polity2.tot.models

sanitation.tot.polity2.cdf.empirical.above0

sanitation.tot.polity2.final.noweight.estimate
sanitation.tot.polity2.final.noweight.se
sanitation.tot.polity2.final.noweight.pvalue

sanitation.tot.polity2.5sig.onesided

sanitation.tot.polity2.tot.models

#primcomp.rate#
primcomp.rate.polity2.tot.models<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$dv=="primcomp.rate"])
primcomp.rate.polity2.max.estimate<-max(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="primcomp.rate"& polity2.finaloutput.combined$keep==1])
primcomp.rate.polity2.min.estimate<-min(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="primcomp.rate"& polity2.finaloutput.combined$keep==1])
primcomp.rate.polity2.5sig.onesided<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$tstat>1.64 & polity2.finaloutput.combined$dv=="primcomp.rate"],na.rm=TRUE)/primcomp.rate.polity2.tot.models
primcomp.rate.polity2.final.noweight.estimate<-mean(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="primcomp.rate"& polity2.finaloutput.combined$keep==1])
primcomp.rate.polity2.final.noweight.se<-mean(polity2.finaloutput.combined$se[polity2.finaloutput.combined$dv=="primcomp.rate"& polity2.finaloutput.combined$keep==1])
primcomp.rate.polity2.final.noweight.tstat<-primcomp.rate.polity2.final.noweight.estimate/primcomp.rate.polity2.final.noweight.se
primcomp.rate.polity2.final.noweight.pvalue<-1-pnorm(primcomp.rate.polity2.final.noweight.tstat)
primcomp.rate.polity2.cdf.empirical.above0<-sum(polity2.finaloutput.combined$keep[(polity2.finaloutput.combined$estimate>0) & polity2.finaloutput.combined$dv=="primcomp.rate"],na.rm=TRUE)/primcomp.rate.polity2.tot.models

primcomp.rate.polity2.cdf.empirical.above0
primcomp.rate.polity2.cdf.sala.above0

primcomp.rate.polity2.final.noweight.estimate
primcomp.rate.polity2.final.noweight.se
primcomp.rate.polity2.final.noweight.pvalue

primcomp.rate.polity2.5sig.onesided

primcomp.rate.polity2.tot.models

#physicians#
physicians.polity2.tot.models<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$dv=="physicians"])
physicians.polity2.max.estimate<-max(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="physicians"& polity2.finaloutput.combined$keep==1])
physicians.polity2.min.estimate<-min(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="physicians"& polity2.finaloutput.combined$keep==1])
physicians.polity2.5sig.onesided<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$tstat>1.64 & polity2.finaloutput.combined$dv=="physicians"],na.rm=TRUE)/physicians.polity2.tot.models
physicians.polity2.final.noweight.estimate<-mean(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="physicians"& polity2.finaloutput.combined$keep==1])
physicians.polity2.final.noweight.se<-mean(polity2.finaloutput.combined$se[polity2.finaloutput.combined$dv=="physicians"& polity2.finaloutput.combined$keep==1])
physicians.polity2.final.noweight.tstat<-physicians.polity2.final.noweight.estimate/physicians.polity2.final.noweight.se
physicians.polity2.final.noweight.pvalue<-1-pnorm(physicians.polity2.final.noweight.tstat)
physicians.polity2.cdf.empirical.above0<-sum(polity2.finaloutput.combined$keep[(polity2.finaloutput.combined$estimate>0) & polity2.finaloutput.combined$dv=="physicians"],na.rm=TRUE)/physicians.polity2.tot.models

physicians.polity2.cdf.empirical.above0
physicians.polity2.cdf.sala.above0

physicians.polity2.final.noweight.estimate
physicians.polity2.final.noweight.se
physicians.polity2.final.noweight.pvalue

physicians.polity2.5sig.onesided

physicians.polity2.tot.models

#lifeexpect#
lifeexpect.polity2.tot.models<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$dv=="lifeexpect"])
lifeexpect.polity2.max.estimate<-max(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="lifeexpect"& polity2.finaloutput.combined$keep==1])
lifeexpect.polity2.min.estimate<-min(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="lifeexpect"& polity2.finaloutput.combined$keep==1])
lifeexpect.polity2.5sig.onesided<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$tstat>1.64 & polity2.finaloutput.combined$dv=="lifeexpect"],na.rm=TRUE)/lifeexpect.polity2.tot.models
lifeexpect.polity2.final.noweight.estimate<-mean(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="lifeexpect"& polity2.finaloutput.combined$keep==1])
lifeexpect.polity2.final.noweight.se<-mean(polity2.finaloutput.combined$se[polity2.finaloutput.combined$dv=="lifeexpect"& polity2.finaloutput.combined$keep==1])
lifeexpect.polity2.final.noweight.tstat<-lifeexpect.polity2.final.noweight.estimate/lifeexpect.polity2.final.noweight.se
lifeexpect.polity2.final.noweight.pvalue<-1-pnorm(lifeexpect.polity2.final.noweight.tstat)
lifeexpect.polity2.cdf.empirical.above0<-sum(polity2.finaloutput.combined$keep[(polity2.finaloutput.combined$estimate>0) & polity2.finaloutput.combined$dv=="lifeexpect"],na.rm=TRUE)/lifeexpect.polity2.tot.models

lifeexpect.polity2.cdf.empirical.above0

lifeexpect.polity2.final.noweight.estimate
lifeexpect.polity2.final.noweight.se
lifeexpect.polity2.final.noweight.pvalue

lifeexpect.polity2.5sig.onesided

lifeexpect.polity2.tot.models

#beds#
beds.polity2.tot.models<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$dv=="beds"])
beds.polity2.max.estimate<-max(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="beds"& polity2.finaloutput.combined$keep==1])
beds.polity2.min.estimate<-min(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="beds"& polity2.finaloutput.combined$keep==1])
beds.polity2.5sig.onesided<-sum(polity2.finaloutput.combined$keep[polity2.finaloutput.combined$tstat>1.64 & polity2.finaloutput.combined$dv=="beds"],na.rm=TRUE)/beds.polity2.tot.models
beds.polity2.final.noweight.estimate<-mean(polity2.finaloutput.combined$estimate[polity2.finaloutput.combined$dv=="beds"& polity2.finaloutput.combined$keep==1])
beds.polity2.final.noweight.se<-mean(polity2.finaloutput.combined$se[polity2.finaloutput.combined$dv=="beds"& polity2.finaloutput.combined$keep==1])
beds.polity2.final.noweight.tstat<-beds.polity2.final.noweight.estimate/beds.polity2.final.noweight.se
beds.polity2.final.noweight.pvalue<-1-pnorm(beds.polity2.final.noweight.tstat)
beds.polity2.cdf.empirical.above0<-sum(polity2.finaloutput.combined$keep[(polity2.finaloutput.combined$estimate>0) & polity2.finaloutput.combined$dv=="beds"],na.rm=TRUE)/beds.polity2.tot.models

beds.polity2.cdf.empirical.above0

beds.polity2.final.noweight.estimate
beds.polity2.final.noweight.se
beds.polity2.final.noweight.pvalue

beds.polity2.5sig.onesided

beds.polity2.tot.models


###ADDRESS MISSING DATA ISSUE###

#Create Imputed Datasets#
install.packages("Amelia")
library("Amelia")

save(a.out, file = "imputations.RData")

full.trim <- subset(full, full$year>1974)
full.trim <- subset(full.trim, select=c("name","code","cowcode","cowyear","country","year","yearcode","unstable.exl","pupilsteachers.sec.rat", "pupilsteachers.prim.rat", "enrollmentrate.sec", "enrollmentrate.prim", "immunizdpt", "water.tot", "measles", "infantmortrate", "deathrate", "primcomp.rate", "sanitation.tot", "physicians", "beds", "lifeexpect", "fh.civilliberties","fh.press","democracy","polity2","gdppc","urb.pertotpop","poptot","area","popdens","africa","asia","ceurope","meast","nam","sam","scan","musl80","cath80","odapercgni","elf85","pop14","pop65"))
full.trim <- subset(full.trim,is.na(full.trim$unstable.exl)==FALSE)

write.dta(full.trim,"full.trim")

a.out <- amelia(full.trim, m = 3, idvars = c("name","code","cowcode","cowyear","yearcode","unstable.exl","africa","asia","ceurope","meast","nam","sam","scan"), ts = "year", cs = "country",polytime = 2, intercs = TRUE, p2s = 2,  empri = .01*nrow(full.trim))
mdesc(a.out)


save(a.out, file = "mythimputations.RData")
write.amelia(obj=a.out, file.stem = "full.trim.imp")

full.trim.imp1<-read.csv("full.trim.imp1.csv")
stable.imp1<-subset(full.trim.imp1, unstable.exl==0)
  
###ALL ESTIMATES FOR POLITY2 MEASURE###

###Polity2###
###l0###

for (i in 1:98) {
  for (k in dvlist) {
    eval(parse(text=paste("l0.",k,"output",i,"<-blank.mat",sep="")))
    eval(parse(text=paste("l0.",k,"output",i,"$modelnum<-",i,sep="")))
    eval(parse(text=paste("l0.",k,"output",i,"$lag<-0",sep=""))) 
  }
}

for (k in dvlist) {
  for (j in 16:51) {
    data<-subset(stable.imp1,year==sum(c(1959,j)))
    eval(parse(text=paste("data$publicgood<-data$",k,sep="")))
    try(model1 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model2 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model3 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model4 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model5 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model6 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model7 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model8 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model9 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model10 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model11 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model12 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model13 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model14 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model15 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model16 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model17 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model18 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model19 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model20 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model21 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model22 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model23 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model24 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model25 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model26 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model27 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model28 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model29 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model30 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model31 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model32 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model33 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model34 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model35 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model36 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model37 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model38 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model39 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model40 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model41 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model42 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model43 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model44 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model45 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model46 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model47 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model48 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model49 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model50 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model51 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model52 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model53 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model54 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model55 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model56 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model57 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model58 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model59 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model60 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model61 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model62 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model63 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + pop14 + pop65+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model64 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model65 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model66 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model67 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model68 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model69 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model70 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model71 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model72 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model73 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model74 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model75 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model76 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model77 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model78 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model79 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model80 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model81 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model82 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model83 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + area+ pop14 + pop65+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model84 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model85 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model86 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model87 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model88 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model89 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model90 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model91 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model92 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ pop14 + pop65+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model93 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model94 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model95 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model96 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model97 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model98 <- zelig(publicgood ~ polity2 + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ pop14 + pop65+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)        
    for (i in 1:98) {
      try(eval(parse(text=paste("l0.",k,"output",i,"[j,2:5]<-summary(model",i,")$coefficients[2,c(1,2,3,4)]",sep=""))), silent=TRUE)
      try(eval(parse(text=paste("l0.",k,"output",i,"[j,8]<-summary(model",i,")$df[2]+summary(model",i,")$df[1]",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("l0.",k,"output",i,"[j,10]<-summary(model",i,")$adj.r.squared",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("rm(model",i,")",sep=""))), silent=TRUE)
    }
  }
}

for (k in dvlist) {
  eval(parse(text=paste("full.l0.",k,"output<-rbind(l0.",k,"output1,l0.",k,"output2,l0.",k,"output3,l0.",k,"output4,l0.",k,"output5,l0.",k,"output6,l0.",k,"output7,l0.",k,"output8,l0.",k,"output9,l0.",k,"output10,l0.",k,"output11,l0.",k,"output12,l0.",k,"output13,l0.",k,"output14,l0.",k,"output15,l0.",k,"output16,l0.",k,"output17,l0.",k,"output18,l0.",k,"output19,l0.",k,"output20,l0.",k,"output21,l0.",k,"output22,l0.",k,"output23,l0.",k,"output24,l0.",k,"output25,l0.",k,"output26,l0.",k,"output27,l0.",k,"output28,l0.",k,"output29,l0.",k,"output30,l0.",k,"output31,l0.",k,"output32,l0.",k,"output33,l0.",k,"output34,l0.",k,"output35,l0.",k,"output36,l0.",k,"output37,l0.",k,"output38,l0.",k,"output39,l0.",k,"output40,l0.",k,"output41,l0.",k,"output42,l0.",k,"output43,l0.",k,"output44,l0.",k,"output45,l0.",k,"output46,l0.",k,"output47,l0.",k,"output48,l0.",k,"output49,l0.",k,"output50,l0.",k,"output51,l0.",k,"output52,l0.",k,"output53,l0.",k,"output54,l0.",k,"output55,l0.",k,"output56,l0.",k,"output57,l0.",k,"output58,l0.",k,"output59,l0.",k,"output60,l0.",k,"output61,l0.",k,"output62,l0.",k,"output63,l0.",k,"output64,l0.",k,"output65,l0.",k,"output66,l0.",k,"output67,l0.",k,"output68,l0.",k,"output69,l0.",k,"output70,l0.",k,"output71,l0.",k,"output72,l0.",k,"output73,l0.",k,"output74,l0.",k,"output75,l0.",k,"output76,l0.",k,"output77,l0.",k,"output78,l0.",k,"output79,l0.",k,"output80,l0.",k,"output81,l0.",k,"output82,l0.",k,"output83,l0.",k,"output84,l0.",k,"output85,l0.",k,"output86,l0.",k,"output87,l0.",k,"output88,l0.",k,"output89,l0.",k,"output90,l0.",k,"output91,l0.",k,"output92,l0.",k,"output93,l0.",k,"output94,l0.",k,"output95,l0.",k,"output96,l0.",k,"output97,l0.",k,"output98)",sep="")))
}

###CREATING FINAL OUTPUT###

for (k in dvlist) {
  eval(parse(text=paste(k,".polity2.finaloutput.imp<-rbind(full.l0.",k,"output)",sep="")))
}

fh.civilliberties.polity2.finaloutput.imp$dv="fh.civilliberties"
fh.press.polity2.finaloutput.imp$dv="fh.press"
deathrate.polity2.finaloutput.imp$dv="deathrate"
infantmortrate.polity2.finaloutput.imp$dv="infantmortrate"
immunizdpt.polity2.finaloutput.imp$dv="immunizdpt"
measles.polity2.finaloutput.imp$dv="measles"
water.tot.polity2.finaloutput.imp$dv="water.tot"
pupilsteachers.prim.rat.polity2.finaloutput.imp$dv="pupilsteachers.prim.rat"
pupilsteachers.sec.rat.polity2.finaloutput.imp$dv="pupilsteachers.sec.rat"
enrollmentrate.sec.polity2.finaloutput.imp$dv="enrollmentrate.sec"
enrollmentrate.prim.polity2.finaloutput.imp$dv="enrollmentrate.prim"
primcomp.rate.polity2.finaloutput.imp$dv="primcomp.rate"
sanitation.tot.polity2.finaloutput.imp$dv="sanitation.tot"
physicians.polity2.finaloutput.imp$dv="physicians"
beds.polity2.finaloutput.imp$dv="beds"
lifeexpect.polity2.finaloutput.imp$dv="lifeexpect"

polity2.finaloutput.imp.combined<-rbind(fh.civilliberties.polity2.finaloutput.imp, fh.press.polity2.finaloutput.imp, deathrate.polity2.finaloutput.imp, infantmortrate.polity2.finaloutput.imp, immunizdpt.polity2.finaloutput.imp, measles.polity2.finaloutput.imp, water.tot.polity2.finaloutput.imp, pupilsteachers.prim.rat.polity2.finaloutput.imp, pupilsteachers.sec.rat.polity2.finaloutput.imp, enrollmentrate.sec.polity2.finaloutput.imp, enrollmentrate.prim.polity2.finaloutput.imp, primcomp.rate.polity2.finaloutput.imp, sanitation.tot.polity2.finaloutput.imp, physicians.polity2.finaloutput.imp, beds.polity2.finaloutput.imp, lifeexpect.polity2.finaloutput.imp)

polity2.finaloutput.imp.combined<-subset(polity2.finaloutput.imp.combined,polity2.finaloutput.imp.combined$year>1974)
polity2.finaloutput.imp.combined$keep<-1
polity2.finaloutput.imp.combined$keep[is.na(polity2.finaloutput.imp.combined$n)==TRUE]<-0
polity2.finaloutput.imp.combined$keep[is.na(polity2.finaloutput.imp.combined$se)==TRUE]<-0

write.dta(polity2.finaloutput.imp.combined,"polity2.finaloutput.imp.combined.dta")


###CREATING FIGURES###

##Figure 4a##
pdf("fig4b-education.imp.pdf", width=10.5, height=7.65)
par(mfcol=c(2,3))
par(cex.axis=1.5)
par(cex.lab=1.5)
par(cex.main=1.5)

#1. Primary Enrollment Rate#
plot(density(polity2.finaloutput.imp.combined$tstat[polity2.finaloutput.imp.combined$dv=="enrollmentrate.prim" & polity2.finaloutput.imp.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Enrollment Rate Primary (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="enrollmentrate.prim" & polity2.finaloutput.combined$keep==1 & polity2.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(prim.enroll)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
legend("topright", legend=c("Imputation","Listwise Deletion"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#2. Pupil Teacher Ratio (Secondary)#
plot(density(polity2.finaloutput.imp.combined$tstat[polity2.finaloutput.imp.combined$dv=="pupilsteachers.sec.rat" & polity2.finaloutput.imp.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Pupil Teacher Ratio Secondary (-)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="pupilsteachers.sec.rat" & polity2.finaloutput.combined$keep==1 & polity2.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(sec.pupils)")
abline(v=0, lwd=1)
abline(v=-1.64, lwd=1, lty=2)
text(-2.45,.3,"t=-1.64", cex=1.25)
legend("topleft", legend=c("Imputation","Listwise Deletion"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#3. Secondary Enrollment Rate#
plot(density(polity2.finaloutput.imp.combined$tstat[polity2.finaloutput.imp.combined$dv=="enrollmentrate.sec" & polity2.finaloutput.imp.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Enrollment Rate Secondary (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="enrollmentrate.sec" & polity2.finaloutput.combined$keep==1 & polity2.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.25, pch=0,lty=2)
mtext("(sec.enroll)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
legend("topright", legend=c("Imputation","Listwise Deletion"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#4. Pupil Teacher Ratio (Primary)#
plot(density(polity2.finaloutput.imp.combined$tstat[polity2.finaloutput.imp.combined$dv=="pupilsteachers.prim.rat" & polity2.finaloutput.imp.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Pupil Teacher Ratio Primary (-)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="pupilsteachers.prim.rat" & polity2.finaloutput.combined$keep==1 & polity2.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(prim.pupils)")
abline(v=0, lwd=1)
abline(v=-1.64, lwd=1, lty=2)
text(-2.45,.3,"t=-1.64", cex=1.25)
legend("topleft", legend=c("Imputation","Listwise Deletion"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#5. Primary Completion Rate#
plot(density(polity2.finaloutput.imp.combined$tstat[polity2.finaloutput.imp.combined$dv=="primcomp.rate" & polity2.finaloutput.imp.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Completion Rate Primary (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="primcomp.rate" & polity2.finaloutput.combined$keep==1 & polity2.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(prim.comp)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
legend("topright", legend=c("Imputation","Listwise Deletion"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")
dev.off()

##Figure 4b##
pdf("fig4b-health.imp.pdf", width=10.5, height=11.5)
par(mfcol=c(3,3))
par(cex.axis=1.5)
par(cex.lab=1.5)
par(cex.main=1.5)

#1. Water Total#
plot(density(polity2.finaloutput.imp.combined$tstat[polity2.finaloutput.imp.combined$dv=="water.tot" & polity2.finaloutput.imp.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Water Access (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="water.tot" & polity2.finaloutput.combined$keep==1 & polity2.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(water)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
legend("topright", legend=c("Imputation","Listwise Deletion"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#2. DPT Immunization#
plot(density(polity2.finaloutput.imp.combined$tstat[polity2.finaloutput.imp.combined$dv=="immunizdpt" & polity2.finaloutput.imp.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="DPT Immunization (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="immunizdpt" & polity2.finaloutput.combined$keep==1 & polity2.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(dpt.im)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
legend("topright", legend=c("Imputation","Listwise Deletion"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#3. Infant Mortality Rate#
plot(density(polity2.finaloutput.imp.combined$tstat[polity2.finaloutput.imp.combined$dv=="infantmortrate" & polity2.finaloutput.imp.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Infant Mortality Rate (-)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="infantmortrate" & polity2.finaloutput.combined$keep==1],na.rm=TRUE & polity2.finaloutput.combined$lag==1), col="red", lwd=1.5, pch=0,lty=2)
mtext("(infmort)")
abline(v=0, lwd=1)
abline(v=-1.64, lwd=1, lty=2)
text(-2.45,.3,"t=-1.64", cex=1.25)
legend("topleft", legend=c("Imputation","Listwise Deletion"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#4. Sanitation#
plot(density(polity2.finaloutput.imp.combined$tstat[polity2.finaloutput.imp.combined$dv=="sanitation.tot" & polity2.finaloutput.imp.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Sanitation Access (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="sanitation.tot" & polity2.finaloutput.combined$keep==1 & polity2.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(sanitation)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
legend("topright", legend=c("Imputation","Listwise Deletion"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#5. Physicians#
plot(density(polity2.finaloutput.imp.combined$tstat[polity2.finaloutput.imp.combined$dv=="physicians" & polity2.finaloutput.imp.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Physicians (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="physicians" & polity2.finaloutput.combined$keep==1 & polity2.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(physicians)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
legend("topright", legend=c("Imputation","Listwise Deletion"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#6. Death Rate#
plot(density(polity2.finaloutput.imp.combined$tstat[polity2.finaloutput.imp.combined$dv=="deathrate" & polity2.finaloutput.imp.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Death Rate (-)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="deathrate" & polity2.finaloutput.combined$keep==1 & polity2.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(death)")
abline(v=0, lwd=1)
abline(v=-1.64, lwd=1, lty=2)
text(-2.45,.3,"t=-1.64", cex=1.25)
legend("topleft", legend=c("Imputation","Listwise Deletion"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#7. Measles Immunization#
plot(density(polity2.finaloutput.imp.combined$tstat[polity2.finaloutput.imp.combined$dv=="measles" & polity2.finaloutput.imp.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Measles Immunization (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="measles" & polity2.finaloutput.combined$keep==1 & polity2.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(measles.im)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
legend("topright", legend=c("Imputation","Listwise Deletion"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#8. Beds#
plot(density(polity2.finaloutput.imp.combined$tstat[polity2.finaloutput.imp.combined$dv=="beds" & polity2.finaloutput.imp.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Beds (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="beds" & polity2.finaloutput.combined$keep==1 & polity2.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(beds)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
legend("topright", legend=c("Imputation","Listwise Deletion"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#9. Life Expectancy#
plot(density(polity2.finaloutput.imp.combined$tstat[polity2.finaloutput.imp.combined$dv=="lifeexpect" & polity2.finaloutput.imp.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Life Expectancy (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(polity2.finaloutput.combined$tstat[polity2.finaloutput.combined$dv=="lifeexpect" & polity2.finaloutput.combined$keep==1 & polity2.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(lifeexpect)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
legend("topright", legend=c("Imputation","Listwise Deletion"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")
dev.off()



###CONSIDERING SENSITIVITY TO DEMOCRACY MEASURE###

dvlist<-c("pupilsteachers.sec.rat", "pupilsteachers.prim.rat", "enrollmentrate.sec", "enrollmentrate.prim", "immunizdpt", "water.tot", "measles", "infantmortrate", "deathrate", "primcomp.rate", "sanitation.tot", "physicians", "beds", "lifeexpect", "fh.civilliberties","fh.press")

id<-seq(1:51)
vyear<-unique(full$year)
vyear <- vyear[order(vyear)]
blank.mat <- matrix(data = NA, nrow=length(vyear), ncol=10)
colnames(blank.mat)<-c("year","estimate", "se", "tstat","pvalue","modelnum","dv","n","lag","adjrsq")
blank.mat<-data.frame(blank.mat)
blank.mat$year<-vyear

for (i in 1:98) {
  for (k in dvlist) {
    eval(parse(text=paste("l0.",k,"output",i,"<-blank.mat",sep="")))
    eval(parse(text=paste("l0.",k,"output",i,"$modelnum<-",i,sep="")))
    eval(parse(text=paste("l0.",k,"output",i,"$lag<-0",sep=""))) 
  }
}

for (k in dvlist) {
  for (j in 16:51) {
    data<-subset(full,year==sum(c(1959,j)))
    eval(parse(text=paste("data$publicgood<-data$",k,sep="")))
    try(model1 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model2 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model3 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model4 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model5 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model6 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model7 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model8 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ popdens, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model9 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model10 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model11 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model12 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model13 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model14 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model15 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model16 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model17 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model18 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model19 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model20 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model21 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model22 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model23 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model24 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model25 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model26 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model27 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model28 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model29 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ africa + asia + ceurope + meast + nam + sam + scan, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model30 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model31 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model32 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model33 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model34 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model35 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model36 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model37 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model38 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model39 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model40 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model41 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model42 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model43 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model44 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model45 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model46 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model47 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model48 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model49 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model50 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model51 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model52 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model53 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model54 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model55 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model56 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model57 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model58 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model59 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model60 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model61 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model62 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model63 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + pop14 + pop65+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model64 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model65 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ africa + asia + ceurope + meast + nam + sam + scan+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model66 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model67 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model68 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model69 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model70 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model71 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model72 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model73 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ popdens+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model74 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model75 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model76 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model77 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model78 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model79 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model80 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model81 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model82 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ musl80 + cath80+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model83 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + area+ pop14 + pop65+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model84 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model85 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14 + pop65, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model86 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model87 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model88 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model89 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model90 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model91 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens+ musl80 + cath80+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model92 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens+ pop14 + pop65+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model93 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14 + pop65+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model94 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model95 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + popdens+ africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model96 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ musl80 + cath80+ pop14 + pop65+ odapercgni, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model97 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + africa + asia + ceurope + meast + nam + sam + scan+ pop14 + pop65+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)      
    try(model98 <- zelig(publicgood ~ democracy.cgv + log(gdppc) + urb.pertotpop + poptot + musl80 + cath80+ pop14 + pop65+ odapercgni+ elf85, model = "ls", robust=TRUE, data = data), silent=TRUE)        
    for (i in 1:98) {
      try(eval(parse(text=paste("l0.",k,"output",i,"[j,2:5]<-summary(model",i,")$coefficients[2,c(1,2,3,4)]",sep=""))), silent=TRUE)
      try(eval(parse(text=paste("l0.",k,"output",i,"[j,8]<-summary(model",i,")$df[2]+summary(model",i,")$df[1]",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("l0.",k,"output",i,"[j,10]<-summary(model",i,")$adj.r.squared",sep=""))), silent=TRUE)    
      try(eval(parse(text=paste("rm(model",i,")",sep=""))), silent=TRUE)
    }
  }
}


for (k in dvlist) {
  eval(parse(text=paste("full.l0.",k,"output<-rbind(l0.",k,"output1,l0.",k,"output2,l0.",k,"output3,l0.",k,"output4,l0.",k,"output5,l0.",k,"output6,l0.",k,"output7,l0.",k,"output8,l0.",k,"output9,l0.",k,"output10,l0.",k,"output11,l0.",k,"output12,l0.",k,"output13,l0.",k,"output14,l0.",k,"output15,l0.",k,"output16,l0.",k,"output17,l0.",k,"output18,l0.",k,"output19,l0.",k,"output20,l0.",k,"output21,l0.",k,"output22,l0.",k,"output23,l0.",k,"output24,l0.",k,"output25,l0.",k,"output26,l0.",k,"output27,l0.",k,"output28,l0.",k,"output29,l0.",k,"output30,l0.",k,"output31,l0.",k,"output32,l0.",k,"output33,l0.",k,"output34,l0.",k,"output35,l0.",k,"output36,l0.",k,"output37,l0.",k,"output38,l0.",k,"output39,l0.",k,"output40,l0.",k,"output41,l0.",k,"output42,l0.",k,"output43,l0.",k,"output44,l0.",k,"output45,l0.",k,"output46,l0.",k,"output47,l0.",k,"output48,l0.",k,"output49,l0.",k,"output50,l0.",k,"output51,l0.",k,"output52,l0.",k,"output53,l0.",k,"output54,l0.",k,"output55,l0.",k,"output56,l0.",k,"output57,l0.",k,"output58,l0.",k,"output59,l0.",k,"output60,l0.",k,"output61,l0.",k,"output62,l0.",k,"output63,l0.",k,"output64,l0.",k,"output65,l0.",k,"output66,l0.",k,"output67,l0.",k,"output68,l0.",k,"output69,l0.",k,"output70,l0.",k,"output71,l0.",k,"output72,l0.",k,"output73,l0.",k,"output74,l0.",k,"output75,l0.",k,"output76,l0.",k,"output77,l0.",k,"output78,l0.",k,"output79,l0.",k,"output80,l0.",k,"output81,l0.",k,"output82,l0.",k,"output83,l0.",k,"output84,l0.",k,"output85,l0.",k,"output86,l0.",k,"output87,l0.",k,"output88,l0.",k,"output89,l0.",k,"output90,l0.",k,"output91,l0.",k,"output92,l0.",k,"output93,l0.",k,"output94,l0.",k,"output95,l0.",k,"output96,l0.",k,"output97,l0.",k,"output98)",sep="")))
}

###CREATING FINAL OUTPUT###

for (k in dvlist) {
  eval(parse(text=paste(k,".democracy.cgv.finaloutput.imp<-rbind(full.l0.",k,"output)",sep="")))
}

fh.civilliberties.democracy.cgv.finaloutput.imp$dv="fh.civilliberties"
fh.press.democracy.cgv.finaloutput.imp$dv="fh.press"
deathrate.democracy.cgv.finaloutput.imp$dv="deathrate"
infantmortrate.democracy.cgv.finaloutput.imp$dv="infantmortrate"
immunizdpt.democracy.cgv.finaloutput.imp$dv="immunizdpt"
measles.democracy.cgv.finaloutput.imp$dv="measles"
water.tot.democracy.cgv.finaloutput.imp$dv="water.tot"
pupilsteachers.prim.rat.democracy.cgv.finaloutput.imp$dv="pupilsteachers.prim.rat"
pupilsteachers.sec.rat.democracy.cgv.finaloutput.imp$dv="pupilsteachers.sec.rat"
enrollmentrate.sec.democracy.cgv.finaloutput.imp$dv="enrollmentrate.sec"
enrollmentrate.prim.democracy.cgv.finaloutput.imp$dv="enrollmentrate.prim"
primcomp.rate.democracy.cgv.finaloutput.imp$dv="primcomp.rate"
sanitation.tot.democracy.cgv.finaloutput.imp$dv="sanitation.tot"
physicians.democracy.cgv.finaloutput.imp$dv="physicians"
beds.democracy.cgv.finaloutput.imp$dv="beds"
lifeexpect.democracy.cgv.finaloutput.imp$dv="lifeexpect"

democracy.cgv.finaloutput.combined<-rbind(fh.civilliberties.democracy.cgv.finaloutput.imp, fh.press.democracy.cgv.finaloutput.imp, deathrate.democracy.cgv.finaloutput.imp, infantmortrate.democracy.cgv.finaloutput.imp, immunizdpt.democracy.cgv.finaloutput.imp, measles.democracy.cgv.finaloutput.imp, water.tot.democracy.cgv.finaloutput.imp, pupilsteachers.prim.rat.democracy.cgv.finaloutput.imp, pupilsteachers.sec.rat.democracy.cgv.finaloutput.imp, enrollmentrate.sec.democracy.cgv.finaloutput.imp, enrollmentrate.prim.democracy.cgv.finaloutput.imp, primcomp.rate.democracy.cgv.finaloutput.imp, sanitation.tot.democracy.cgv.finaloutput.imp, physicians.democracy.cgv.finaloutput.imp, beds.democracy.cgv.finaloutput.imp, lifeexpect.democracy.cgv.finaloutput.imp)

democracy.cgv.finaloutput.combined<-subset(democracy.cgv.finaloutput.combined,democracy.cgv.finaloutput.combined$year>1974)
democracy.cgv.finaloutput.combined$keep<-1
democracy.cgv.finaloutput.combined$keep[is.na(democracy.cgv.finaloutput.combined$n)==TRUE]<-0
democracy.cgv.finaloutput.combined$keep[is.na(democracy.cgv.finaloutput.combined$se)==TRUE]<-0

write.dta(democracy.cgv.finaloutput.combined,"democracy.cgv.finaloutput.combined.dta")


###CREATING FIGURES###

##Figure 5a##
pdf("fig5a-education.cgv.pdf", width=10.5, height=7.65)
par(mfcol=c(2,3))
par(cex.axis=1.5)
par(cex.lab=1.5)
par(cex.main=1.5)

#1. Primary Enrollment Rate#
plot(density(democracy.cgv.finaloutput.combined$tstat[democracy.cgv.finaloutput.combined$dv=="enrollmentrate.prim" & democracy.cgv.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Enrollment Rate Primary (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="enrollmentrate.prim" & democracy.finaloutput.combined$keep==1 & democracy.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(prim.enroll)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
legend("topright", legend=c("CGV","GWF"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#2. Pupil Teacher Ratio (Secondary)#
plot(density(democracy.cgv.finaloutput.combined$tstat[democracy.cgv.finaloutput.combined$dv=="pupilsteachers.sec.rat" & democracy.cgv.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Pupil Teacher Ratio Secondary (-)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="pupilsteachers.sec.rat" & democracy.finaloutput.combined$keep==1 & democracy.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(sec.pupils)")
abline(v=0, lwd=1)
abline(v=-1.64, lwd=1, lty=2)
text(-2.45,.3,"t=-1.64", cex=1.25)
legend("topleft", legend=c("CGV","GWF"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#3. Secondary Enrollment Rate#
plot(density(democracy.cgv.finaloutput.combined$tstat[democracy.cgv.finaloutput.combined$dv=="enrollmentrate.sec" & democracy.cgv.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Enrollment Rate Secondary (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="enrollmentrate.sec" & democracy.finaloutput.combined$keep==1 & democracy.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.25, pch=0,lty=2)
mtext("(sec.enroll)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
legend("topright", legend=c("CGV","GWF"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#4. Pupil Teacher Ratio (Primary)#
plot(density(democracy.cgv.finaloutput.combined$tstat[democracy.cgv.finaloutput.combined$dv=="pupilsteachers.prim.rat" & democracy.cgv.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Pupil Teacher Ratio Primary (-)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="pupilsteachers.prim.rat" & democracy.finaloutput.combined$keep==1 & democracy.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(prim.pupils)")
abline(v=0, lwd=1)
abline(v=-1.64, lwd=1, lty=2)
text(-2.45,.3,"t=-1.64", cex=1.25)
legend("topleft", legend=c("CGV","GWF"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#5. Primary Completion Rate#
plot(density(democracy.cgv.finaloutput.combined$tstat[democracy.cgv.finaloutput.combined$dv=="primcomp.rate" & democracy.cgv.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Completion Rate Primary (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="primcomp.rate" & democracy.finaloutput.combined$keep==1 & democracy.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(prim.comp)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
legend("topright", legend=c("CGV","GWF"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")
dev.off()

##Figure 5b##
pdf("fig5b-health.cgv.pdf", width=10.5, height=11.5)
par(mfcol=c(3,3))
par(cex.axis=1.5)
par(cex.lab=1.5)
par(cex.main=1.5)

#1. Water Total#
plot(density(democracy.cgv.finaloutput.combined$tstat[democracy.cgv.finaloutput.combined$dv=="water.tot" & democracy.cgv.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Water Access (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="water.tot" & democracy.finaloutput.combined$keep==1 & democracy.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(water)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
legend("topright", legend=c("CGV","GWF"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#2. DPT Immunization#
plot(density(democracy.cgv.finaloutput.combined$tstat[democracy.cgv.finaloutput.combined$dv=="immunizdpt" & democracy.cgv.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="DPT Immunization (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="immunizdpt" & democracy.finaloutput.combined$keep==1 & democracy.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(dpt.im)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
legend("topright", legend=c("CGV","GWF"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#3. Infant Mortality Rate#
plot(density(democracy.cgv.finaloutput.combined$tstat[democracy.cgv.finaloutput.combined$dv=="infantmortrate" & democracy.cgv.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Infant Mortality Rate (-)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="infantmortrate" & democracy.finaloutput.combined$keep==1],na.rm=TRUE & democracy.finaloutput.combined$lag==1), col="red", lwd=1.5, pch=0,lty=2)
mtext("(infmort)")
abline(v=0, lwd=1)
abline(v=-1.64, lwd=1, lty=2)
text(-2.45,.3,"t=-1.64", cex=1.25)
legend("topleft", legend=c("CGV","GWF"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#4. Sanitation#
plot(density(democracy.cgv.finaloutput.combined$tstat[democracy.cgv.finaloutput.combined$dv=="sanitation.tot" & democracy.cgv.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Sanitation Access (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="sanitation.tot" & democracy.finaloutput.combined$keep==1 & democracy.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(sanitation)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
legend("topright", legend=c("CGV","GWF"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#5. Physicians#
plot(density(democracy.cgv.finaloutput.combined$tstat[polity2.finaloutput.imp.combined$dv=="physicians" & democracy.cgv.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Physicians (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="physicians" & democracy.finaloutput.combined$keep==1 & democracy.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(physicians)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
legend("topright", legend=c("CGV","GWF"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#6. Death Rate#
plot(density(democracy.cgv.finaloutput.combined$tstat[democracy.cgv.finaloutput.combined$dv=="deathrate" & democracy.cgv.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Death Rate (-)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="deathrate" & democracy.finaloutput.combined$keep==1 & democracy.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(death)")
abline(v=0, lwd=1)
abline(v=-1.64, lwd=1, lty=2)
text(-2.45,.3,"t=-1.64", cex=1.25)
legend("topleft", legend=c("CGV","GWF"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#7. Measles Immunization#
plot(density(democracy.cgv.finaloutput.combined$tstat[democracy.cgv.finaloutput.combined$dv=="measles" & democracy.cgv.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Measles Immunization (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="measles" & democracy.finaloutput.combined$keep==1 & democracy.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(measles.im)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
legend("topright", legend=c("CGV","GWF"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#8. Beds#
plot(density(democracy.cgv.finaloutput.combined$tstat[democracy.cgv.finaloutput.combined$dv=="beds" & democracy.cgv.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Beds (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="beds" & democracy.finaloutput.combined$keep==1 & democracy.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(beds)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
legend("topright", legend=c("CGV","GWF"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")

#9. Life Expectancy#
plot(density(democracy.cgv.finaloutput.combined$tstat[democracy.cgv.finaloutput.combined$dv=="lifeexpect" & democracy.cgv.finaloutput.combined$keep==1],na.rm=TRUE), xlab="t statistic", ylab="Density", main="Life Expectancy (+)", col="darkblue", lwd=1.5, pch=0,xlim=c(-4,4),ylim=c(0,.65))
lines(density(democracy.finaloutput.combined$tstat[democracy.finaloutput.combined$dv=="lifeexpect" & democracy.finaloutput.combined$keep==1 & democracy.finaloutput.combined$lag==1],na.rm=TRUE), col="red", lwd=1.5, pch=0,lty=2)
mtext("(lifeexpect)")
abline(v=0, lwd=1)
abline(v=1.64, lwd=1, lty=2)
text(2.45,.3,"t=1.64", cex=1.25)
legend("topright", legend=c("CGV","GWF"),col=c("darkblue","red"), lty=c(1,2), cex=1.25,bty="n")
dev.off()


